import reflex as rx

class Fa500Px(rx.Component):
    library = "react-icons/fa"
    tag = "Fa500Px"


class FaAccessibleIcon(rx.Component):
    library = "react-icons/fa"
    tag = "FaAccessibleIcon"


class FaAccusoft(rx.Component):
    library = "react-icons/fa"
    tag = "FaAccusoft"


class FaAcquisitionsIncorporated(rx.Component):
    library = "react-icons/fa"
    tag = "FaAcquisitionsIncorporated"


class FaAdn(rx.Component):
    library = "react-icons/fa"
    tag = "FaAdn"


class FaAdversal(rx.Component):
    library = "react-icons/fa"
    tag = "FaAdversal"


class FaAffiliatetheme(rx.Component):
    library = "react-icons/fa"
    tag = "FaAffiliatetheme"


class FaAirbnb(rx.Component):
    library = "react-icons/fa"
    tag = "FaAirbnb"


class FaAlgolia(rx.Component):
    library = "react-icons/fa"
    tag = "FaAlgolia"


class FaAlipay(rx.Component):
    library = "react-icons/fa"
    tag = "FaAlipay"


class FaAmazonPay(rx.Component):
    library = "react-icons/fa"
    tag = "FaAmazonPay"


class FaAmazon(rx.Component):
    library = "react-icons/fa"
    tag = "FaAmazon"


class FaAmilia(rx.Component):
    library = "react-icons/fa"
    tag = "FaAmilia"


class FaAndroid(rx.Component):
    library = "react-icons/fa"
    tag = "FaAndroid"


class FaAngellist(rx.Component):
    library = "react-icons/fa"
    tag = "FaAngellist"


class FaAngrycreative(rx.Component):
    library = "react-icons/fa"
    tag = "FaAngrycreative"


class FaAngular(rx.Component):
    library = "react-icons/fa"
    tag = "FaAngular"


class FaAppStoreIos(rx.Component):
    library = "react-icons/fa"
    tag = "FaAppStoreIos"


class FaAppStore(rx.Component):
    library = "react-icons/fa"
    tag = "FaAppStore"


class FaApper(rx.Component):
    library = "react-icons/fa"
    tag = "FaApper"


class FaApplePay(rx.Component):
    library = "react-icons/fa"
    tag = "FaApplePay"


class FaApple(rx.Component):
    library = "react-icons/fa"
    tag = "FaApple"


class FaArtstation(rx.Component):
    library = "react-icons/fa"
    tag = "FaArtstation"


class FaAsymmetrik(rx.Component):
    library = "react-icons/fa"
    tag = "FaAsymmetrik"


class FaAtlassian(rx.Component):
    library = "react-icons/fa"
    tag = "FaAtlassian"


class FaAudible(rx.Component):
    library = "react-icons/fa"
    tag = "FaAudible"


class FaAutoprefixer(rx.Component):
    library = "react-icons/fa"
    tag = "FaAutoprefixer"


class FaAvianex(rx.Component):
    library = "react-icons/fa"
    tag = "FaAvianex"


class FaAviato(rx.Component):
    library = "react-icons/fa"
    tag = "FaAviato"


class FaAws(rx.Component):
    library = "react-icons/fa"
    tag = "FaAws"


class FaBandcamp(rx.Component):
    library = "react-icons/fa"
    tag = "FaBandcamp"


class FaBattleNet(rx.Component):
    library = "react-icons/fa"
    tag = "FaBattleNet"


class FaBehanceSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaBehanceSquare"


class FaBehance(rx.Component):
    library = "react-icons/fa"
    tag = "FaBehance"


class FaBimobject(rx.Component):
    library = "react-icons/fa"
    tag = "FaBimobject"


class FaBitbucket(rx.Component):
    library = "react-icons/fa"
    tag = "FaBitbucket"


class FaBitcoin(rx.Component):
    library = "react-icons/fa"
    tag = "FaBitcoin"


class FaBity(rx.Component):
    library = "react-icons/fa"
    tag = "FaBity"


class FaBlackTie(rx.Component):
    library = "react-icons/fa"
    tag = "FaBlackTie"


class FaBlackberry(rx.Component):
    library = "react-icons/fa"
    tag = "FaBlackberry"


class FaBloggerB(rx.Component):
    library = "react-icons/fa"
    tag = "FaBloggerB"


class FaBlogger(rx.Component):
    library = "react-icons/fa"
    tag = "FaBlogger"


class FaBluetoothB(rx.Component):
    library = "react-icons/fa"
    tag = "FaBluetoothB"


class FaBluetooth(rx.Component):
    library = "react-icons/fa"
    tag = "FaBluetooth"


class FaBootstrap(rx.Component):
    library = "react-icons/fa"
    tag = "FaBootstrap"


class FaBtc(rx.Component):
    library = "react-icons/fa"
    tag = "FaBtc"


class FaBuffer(rx.Component):
    library = "react-icons/fa"
    tag = "FaBuffer"


class FaBuromobelexperte(rx.Component):
    library = "react-icons/fa"
    tag = "FaBuromobelexperte"


class FaBuyNLarge(rx.Component):
    library = "react-icons/fa"
    tag = "FaBuyNLarge"


class FaBuysellads(rx.Component):
    library = "react-icons/fa"
    tag = "FaBuysellads"


class FaCanadianMapleLeaf(rx.Component):
    library = "react-icons/fa"
    tag = "FaCanadianMapleLeaf"


class FaCcAmazonPay(rx.Component):
    library = "react-icons/fa"
    tag = "FaCcAmazonPay"


class FaCcAmex(rx.Component):
    library = "react-icons/fa"
    tag = "FaCcAmex"


class FaCcApplePay(rx.Component):
    library = "react-icons/fa"
    tag = "FaCcApplePay"


class FaCcDinersClub(rx.Component):
    library = "react-icons/fa"
    tag = "FaCcDinersClub"


class FaCcDiscover(rx.Component):
    library = "react-icons/fa"
    tag = "FaCcDiscover"


class FaCcJcb(rx.Component):
    library = "react-icons/fa"
    tag = "FaCcJcb"


class FaCcMastercard(rx.Component):
    library = "react-icons/fa"
    tag = "FaCcMastercard"


class FaCcPaypal(rx.Component):
    library = "react-icons/fa"
    tag = "FaCcPaypal"


class FaCcStripe(rx.Component):
    library = "react-icons/fa"
    tag = "FaCcStripe"


class FaCcVisa(rx.Component):
    library = "react-icons/fa"
    tag = "FaCcVisa"


class FaCentercode(rx.Component):
    library = "react-icons/fa"
    tag = "FaCentercode"


class FaCentos(rx.Component):
    library = "react-icons/fa"
    tag = "FaCentos"


class FaChrome(rx.Component):
    library = "react-icons/fa"
    tag = "FaChrome"


class FaChromecast(rx.Component):
    library = "react-icons/fa"
    tag = "FaChromecast"


class FaCloudflare(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloudflare"


class FaCloudscale(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloudscale"


class FaCloudsmith(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloudsmith"


class FaCloudversify(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloudversify"


class FaCodepen(rx.Component):
    library = "react-icons/fa"
    tag = "FaCodepen"


class FaCodiepie(rx.Component):
    library = "react-icons/fa"
    tag = "FaCodiepie"


class FaConfluence(rx.Component):
    library = "react-icons/fa"
    tag = "FaConfluence"


class FaConnectdevelop(rx.Component):
    library = "react-icons/fa"
    tag = "FaConnectdevelop"


class FaContao(rx.Component):
    library = "react-icons/fa"
    tag = "FaContao"


class FaCottonBureau(rx.Component):
    library = "react-icons/fa"
    tag = "FaCottonBureau"


class FaCpanel(rx.Component):
    library = "react-icons/fa"
    tag = "FaCpanel"


class FaCreativeCommonsBy(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommonsBy"


class FaCreativeCommonsNcEu(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommonsNcEu"


class FaCreativeCommonsNcJp(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommonsNcJp"


class FaCreativeCommonsNc(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommonsNc"


class FaCreativeCommonsNd(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommonsNd"


class FaCreativeCommonsPdAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommonsPdAlt"


class FaCreativeCommonsPd(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommonsPd"


class FaCreativeCommonsRemix(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommonsRemix"


class FaCreativeCommonsSa(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommonsSa"


class FaCreativeCommonsSamplingPlus(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommonsSamplingPlus"


class FaCreativeCommonsSampling(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommonsSampling"


class FaCreativeCommonsShare(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommonsShare"


class FaCreativeCommonsZero(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommonsZero"


class FaCreativeCommons(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreativeCommons"


class FaCriticalRole(rx.Component):
    library = "react-icons/fa"
    tag = "FaCriticalRole"


class FaCss3Alt(rx.Component):
    library = "react-icons/fa"
    tag = "FaCss3Alt"


class FaCss3(rx.Component):
    library = "react-icons/fa"
    tag = "FaCss3"


class FaCuttlefish(rx.Component):
    library = "react-icons/fa"
    tag = "FaCuttlefish"


class FaDAndDBeyond(rx.Component):
    library = "react-icons/fa"
    tag = "FaDAndDBeyond"


class FaDAndD(rx.Component):
    library = "react-icons/fa"
    tag = "FaDAndD"


class FaDailymotion(rx.Component):
    library = "react-icons/fa"
    tag = "FaDailymotion"


class FaDashcube(rx.Component):
    library = "react-icons/fa"
    tag = "FaDashcube"


class FaDeezer(rx.Component):
    library = "react-icons/fa"
    tag = "FaDeezer"


class FaDelicious(rx.Component):
    library = "react-icons/fa"
    tag = "FaDelicious"


class FaDeploydog(rx.Component):
    library = "react-icons/fa"
    tag = "FaDeploydog"


class FaDeskpro(rx.Component):
    library = "react-icons/fa"
    tag = "FaDeskpro"


class FaDev(rx.Component):
    library = "react-icons/fa"
    tag = "FaDev"


class FaDeviantart(rx.Component):
    library = "react-icons/fa"
    tag = "FaDeviantart"


class FaDhl(rx.Component):
    library = "react-icons/fa"
    tag = "FaDhl"


class FaDiaspora(rx.Component):
    library = "react-icons/fa"
    tag = "FaDiaspora"


class FaDigg(rx.Component):
    library = "react-icons/fa"
    tag = "FaDigg"


class FaDigitalOcean(rx.Component):
    library = "react-icons/fa"
    tag = "FaDigitalOcean"


class FaDiscord(rx.Component):
    library = "react-icons/fa"
    tag = "FaDiscord"


class FaDiscourse(rx.Component):
    library = "react-icons/fa"
    tag = "FaDiscourse"


class FaDochub(rx.Component):
    library = "react-icons/fa"
    tag = "FaDochub"


class FaDocker(rx.Component):
    library = "react-icons/fa"
    tag = "FaDocker"


class FaDraft2Digital(rx.Component):
    library = "react-icons/fa"
    tag = "FaDraft2Digital"


class FaDribbbleSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaDribbbleSquare"


class FaDribbble(rx.Component):
    library = "react-icons/fa"
    tag = "FaDribbble"


class FaDropbox(rx.Component):
    library = "react-icons/fa"
    tag = "FaDropbox"


class FaDrupal(rx.Component):
    library = "react-icons/fa"
    tag = "FaDrupal"


class FaDyalog(rx.Component):
    library = "react-icons/fa"
    tag = "FaDyalog"


class FaEarlybirds(rx.Component):
    library = "react-icons/fa"
    tag = "FaEarlybirds"


class FaEbay(rx.Component):
    library = "react-icons/fa"
    tag = "FaEbay"


class FaEdgeLegacy(rx.Component):
    library = "react-icons/fa"
    tag = "FaEdgeLegacy"


class FaEdge(rx.Component):
    library = "react-icons/fa"
    tag = "FaEdge"


class FaElementor(rx.Component):
    library = "react-icons/fa"
    tag = "FaElementor"


class FaEllo(rx.Component):
    library = "react-icons/fa"
    tag = "FaEllo"


class FaEmber(rx.Component):
    library = "react-icons/fa"
    tag = "FaEmber"


class FaEmpire(rx.Component):
    library = "react-icons/fa"
    tag = "FaEmpire"


class FaEnvira(rx.Component):
    library = "react-icons/fa"
    tag = "FaEnvira"


class FaErlang(rx.Component):
    library = "react-icons/fa"
    tag = "FaErlang"


class FaEthereum(rx.Component):
    library = "react-icons/fa"
    tag = "FaEthereum"


class FaEtsy(rx.Component):
    library = "react-icons/fa"
    tag = "FaEtsy"


class FaEvernote(rx.Component):
    library = "react-icons/fa"
    tag = "FaEvernote"


class FaExpeditedssl(rx.Component):
    library = "react-icons/fa"
    tag = "FaExpeditedssl"


class FaFacebookF(rx.Component):
    library = "react-icons/fa"
    tag = "FaFacebookF"


class FaFacebookMessenger(rx.Component):
    library = "react-icons/fa"
    tag = "FaFacebookMessenger"


class FaFacebookSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaFacebookSquare"


class FaFacebook(rx.Component):
    library = "react-icons/fa"
    tag = "FaFacebook"


class FaFantasyFlightGames(rx.Component):
    library = "react-icons/fa"
    tag = "FaFantasyFlightGames"


class FaFedex(rx.Component):
    library = "react-icons/fa"
    tag = "FaFedex"


class FaFedora(rx.Component):
    library = "react-icons/fa"
    tag = "FaFedora"


class FaFigma(rx.Component):
    library = "react-icons/fa"
    tag = "FaFigma"


class FaFirefoxBrowser(rx.Component):
    library = "react-icons/fa"
    tag = "FaFirefoxBrowser"


class FaFirefox(rx.Component):
    library = "react-icons/fa"
    tag = "FaFirefox"


class FaFirstOrderAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaFirstOrderAlt"


class FaFirstOrder(rx.Component):
    library = "react-icons/fa"
    tag = "FaFirstOrder"


class FaFirstdraft(rx.Component):
    library = "react-icons/fa"
    tag = "FaFirstdraft"


class FaFlickr(rx.Component):
    library = "react-icons/fa"
    tag = "FaFlickr"


class FaFlipboard(rx.Component):
    library = "react-icons/fa"
    tag = "FaFlipboard"


class FaFly(rx.Component):
    library = "react-icons/fa"
    tag = "FaFly"


class FaFontAwesomeAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaFontAwesomeAlt"


class FaFontAwesomeFlag(rx.Component):
    library = "react-icons/fa"
    tag = "FaFontAwesomeFlag"


class FaFontAwesomeLogoFull(rx.Component):
    library = "react-icons/fa"
    tag = "FaFontAwesomeLogoFull"


class FaFontAwesome(rx.Component):
    library = "react-icons/fa"
    tag = "FaFontAwesome"


class FaFonticonsFi(rx.Component):
    library = "react-icons/fa"
    tag = "FaFonticonsFi"


class FaFonticons(rx.Component):
    library = "react-icons/fa"
    tag = "FaFonticons"


class FaFortAwesomeAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaFortAwesomeAlt"


class FaFortAwesome(rx.Component):
    library = "react-icons/fa"
    tag = "FaFortAwesome"


class FaForumbee(rx.Component):
    library = "react-icons/fa"
    tag = "FaForumbee"


class FaFoursquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaFoursquare"


class FaFreeCodeCamp(rx.Component):
    library = "react-icons/fa"
    tag = "FaFreeCodeCamp"


class FaFreebsd(rx.Component):
    library = "react-icons/fa"
    tag = "FaFreebsd"


class FaFulcrum(rx.Component):
    library = "react-icons/fa"
    tag = "FaFulcrum"


class FaGalacticRepublic(rx.Component):
    library = "react-icons/fa"
    tag = "FaGalacticRepublic"


class FaGalacticSenate(rx.Component):
    library = "react-icons/fa"
    tag = "FaGalacticSenate"


class FaGetPocket(rx.Component):
    library = "react-icons/fa"
    tag = "FaGetPocket"


class FaGgCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaGgCircle"


class FaGg(rx.Component):
    library = "react-icons/fa"
    tag = "FaGg"


class FaGitAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaGitAlt"


class FaGitSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaGitSquare"


class FaGit(rx.Component):
    library = "react-icons/fa"
    tag = "FaGit"


class FaGithubAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaGithubAlt"


class FaGithubSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaGithubSquare"


class FaGithub(rx.Component):
    library = "react-icons/fa"
    tag = "FaGithub"


class FaGitkraken(rx.Component):
    library = "react-icons/fa"
    tag = "FaGitkraken"


class FaGitlab(rx.Component):
    library = "react-icons/fa"
    tag = "FaGitlab"


class FaGitter(rx.Component):
    library = "react-icons/fa"
    tag = "FaGitter"


class FaGlideG(rx.Component):
    library = "react-icons/fa"
    tag = "FaGlideG"


class FaGlide(rx.Component):
    library = "react-icons/fa"
    tag = "FaGlide"


class FaGofore(rx.Component):
    library = "react-icons/fa"
    tag = "FaGofore"


class FaGoodreadsG(rx.Component):
    library = "react-icons/fa"
    tag = "FaGoodreadsG"


class FaGoodreads(rx.Component):
    library = "react-icons/fa"
    tag = "FaGoodreads"


class FaGoogleDrive(rx.Component):
    library = "react-icons/fa"
    tag = "FaGoogleDrive"


class FaGooglePay(rx.Component):
    library = "react-icons/fa"
    tag = "FaGooglePay"


class FaGooglePlay(rx.Component):
    library = "react-icons/fa"
    tag = "FaGooglePlay"


class FaGooglePlusG(rx.Component):
    library = "react-icons/fa"
    tag = "FaGooglePlusG"


class FaGooglePlusSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaGooglePlusSquare"


class FaGooglePlus(rx.Component):
    library = "react-icons/fa"
    tag = "FaGooglePlus"


class FaGoogleWallet(rx.Component):
    library = "react-icons/fa"
    tag = "FaGoogleWallet"


class FaGoogle(rx.Component):
    library = "react-icons/fa"
    tag = "FaGoogle"


class FaGratipay(rx.Component):
    library = "react-icons/fa"
    tag = "FaGratipay"


class FaGrav(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrav"


class FaGripfire(rx.Component):
    library = "react-icons/fa"
    tag = "FaGripfire"


class FaGrunt(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrunt"


class FaGuilded(rx.Component):
    library = "react-icons/fa"
    tag = "FaGuilded"


class FaGulp(rx.Component):
    library = "react-icons/fa"
    tag = "FaGulp"


class FaHackerNewsSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaHackerNewsSquare"


class FaHackerNews(rx.Component):
    library = "react-icons/fa"
    tag = "FaHackerNews"


class FaHackerrank(rx.Component):
    library = "react-icons/fa"
    tag = "FaHackerrank"


class FaHips(rx.Component):
    library = "react-icons/fa"
    tag = "FaHips"


class FaHireAHelper(rx.Component):
    library = "react-icons/fa"
    tag = "FaHireAHelper"


class FaHive(rx.Component):
    library = "react-icons/fa"
    tag = "FaHive"


class FaHooli(rx.Component):
    library = "react-icons/fa"
    tag = "FaHooli"


class FaHornbill(rx.Component):
    library = "react-icons/fa"
    tag = "FaHornbill"


class FaHotjar(rx.Component):
    library = "react-icons/fa"
    tag = "FaHotjar"


class FaHouzz(rx.Component):
    library = "react-icons/fa"
    tag = "FaHouzz"


class FaHtml5(rx.Component):
    library = "react-icons/fa"
    tag = "FaHtml5"


class FaHubspot(rx.Component):
    library = "react-icons/fa"
    tag = "FaHubspot"


class FaIdeal(rx.Component):
    library = "react-icons/fa"
    tag = "FaIdeal"


class FaImdb(rx.Component):
    library = "react-icons/fa"
    tag = "FaImdb"


class FaInnosoft(rx.Component):
    library = "react-icons/fa"
    tag = "FaInnosoft"


class FaInstagramSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaInstagramSquare"


class FaInstagram(rx.Component):
    library = "react-icons/fa"
    tag = "FaInstagram"


class FaInstalod(rx.Component):
    library = "react-icons/fa"
    tag = "FaInstalod"


class FaIntercom(rx.Component):
    library = "react-icons/fa"
    tag = "FaIntercom"


class FaInternetExplorer(rx.Component):
    library = "react-icons/fa"
    tag = "FaInternetExplorer"


class FaInvision(rx.Component):
    library = "react-icons/fa"
    tag = "FaInvision"


class FaIoxhost(rx.Component):
    library = "react-icons/fa"
    tag = "FaIoxhost"


class FaItchIo(rx.Component):
    library = "react-icons/fa"
    tag = "FaItchIo"


class FaItunesNote(rx.Component):
    library = "react-icons/fa"
    tag = "FaItunesNote"


class FaItunes(rx.Component):
    library = "react-icons/fa"
    tag = "FaItunes"


class FaJava(rx.Component):
    library = "react-icons/fa"
    tag = "FaJava"


class FaJediOrder(rx.Component):
    library = "react-icons/fa"
    tag = "FaJediOrder"


class FaJenkins(rx.Component):
    library = "react-icons/fa"
    tag = "FaJenkins"


class FaJira(rx.Component):
    library = "react-icons/fa"
    tag = "FaJira"


class FaJoget(rx.Component):
    library = "react-icons/fa"
    tag = "FaJoget"


class FaJoomla(rx.Component):
    library = "react-icons/fa"
    tag = "FaJoomla"


class FaJsSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaJsSquare"


class FaJs(rx.Component):
    library = "react-icons/fa"
    tag = "FaJs"


class FaJsfiddle(rx.Component):
    library = "react-icons/fa"
    tag = "FaJsfiddle"


class FaKaggle(rx.Component):
    library = "react-icons/fa"
    tag = "FaKaggle"


class FaKeybase(rx.Component):
    library = "react-icons/fa"
    tag = "FaKeybase"


class FaKeycdn(rx.Component):
    library = "react-icons/fa"
    tag = "FaKeycdn"


class FaKickstarterK(rx.Component):
    library = "react-icons/fa"
    tag = "FaKickstarterK"


class FaKickstarter(rx.Component):
    library = "react-icons/fa"
    tag = "FaKickstarter"


class FaKorvue(rx.Component):
    library = "react-icons/fa"
    tag = "FaKorvue"


class FaLaravel(rx.Component):
    library = "react-icons/fa"
    tag = "FaLaravel"


class FaLastfmSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaLastfmSquare"


class FaLastfm(rx.Component):
    library = "react-icons/fa"
    tag = "FaLastfm"


class FaLeanpub(rx.Component):
    library = "react-icons/fa"
    tag = "FaLeanpub"


class FaLess(rx.Component):
    library = "react-icons/fa"
    tag = "FaLess"


class FaLine(rx.Component):
    library = "react-icons/fa"
    tag = "FaLine"


class FaLinkedinIn(rx.Component):
    library = "react-icons/fa"
    tag = "FaLinkedinIn"


class FaLinkedin(rx.Component):
    library = "react-icons/fa"
    tag = "FaLinkedin"


class FaLinode(rx.Component):
    library = "react-icons/fa"
    tag = "FaLinode"


class FaLinux(rx.Component):
    library = "react-icons/fa"
    tag = "FaLinux"


class FaLyft(rx.Component):
    library = "react-icons/fa"
    tag = "FaLyft"


class FaMagento(rx.Component):
    library = "react-icons/fa"
    tag = "FaMagento"


class FaMailchimp(rx.Component):
    library = "react-icons/fa"
    tag = "FaMailchimp"


class FaMandalorian(rx.Component):
    library = "react-icons/fa"
    tag = "FaMandalorian"


class FaMarkdown(rx.Component):
    library = "react-icons/fa"
    tag = "FaMarkdown"


class FaMastodon(rx.Component):
    library = "react-icons/fa"
    tag = "FaMastodon"


class FaMaxcdn(rx.Component):
    library = "react-icons/fa"
    tag = "FaMaxcdn"


class FaMdb(rx.Component):
    library = "react-icons/fa"
    tag = "FaMdb"


class FaMedapps(rx.Component):
    library = "react-icons/fa"
    tag = "FaMedapps"


class FaMediumM(rx.Component):
    library = "react-icons/fa"
    tag = "FaMediumM"


class FaMedium(rx.Component):
    library = "react-icons/fa"
    tag = "FaMedium"


class FaMedrt(rx.Component):
    library = "react-icons/fa"
    tag = "FaMedrt"


class FaMeetup(rx.Component):
    library = "react-icons/fa"
    tag = "FaMeetup"


class FaMegaport(rx.Component):
    library = "react-icons/fa"
    tag = "FaMegaport"


class FaMendeley(rx.Component):
    library = "react-icons/fa"
    tag = "FaMendeley"


class FaMicroblog(rx.Component):
    library = "react-icons/fa"
    tag = "FaMicroblog"


class FaMicrosoft(rx.Component):
    library = "react-icons/fa"
    tag = "FaMicrosoft"


class FaMix(rx.Component):
    library = "react-icons/fa"
    tag = "FaMix"


class FaMixcloud(rx.Component):
    library = "react-icons/fa"
    tag = "FaMixcloud"


class FaMixer(rx.Component):
    library = "react-icons/fa"
    tag = "FaMixer"


class FaMizuni(rx.Component):
    library = "react-icons/fa"
    tag = "FaMizuni"


class FaModx(rx.Component):
    library = "react-icons/fa"
    tag = "FaModx"


class FaMonero(rx.Component):
    library = "react-icons/fa"
    tag = "FaMonero"


class FaNapster(rx.Component):
    library = "react-icons/fa"
    tag = "FaNapster"


class FaNeos(rx.Component):
    library = "react-icons/fa"
    tag = "FaNeos"


class FaNimblr(rx.Component):
    library = "react-icons/fa"
    tag = "FaNimblr"


class FaNodeJs(rx.Component):
    library = "react-icons/fa"
    tag = "FaNodeJs"


class FaNode(rx.Component):
    library = "react-icons/fa"
    tag = "FaNode"


class FaNpm(rx.Component):
    library = "react-icons/fa"
    tag = "FaNpm"


class FaNs8(rx.Component):
    library = "react-icons/fa"
    tag = "FaNs8"


class FaNutritionix(rx.Component):
    library = "react-icons/fa"
    tag = "FaNutritionix"


class FaOctopusDeploy(rx.Component):
    library = "react-icons/fa"
    tag = "FaOctopusDeploy"


class FaOdnoklassnikiSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaOdnoklassnikiSquare"


class FaOdnoklassniki(rx.Component):
    library = "react-icons/fa"
    tag = "FaOdnoklassniki"


class FaOldRepublic(rx.Component):
    library = "react-icons/fa"
    tag = "FaOldRepublic"


class FaOpencart(rx.Component):
    library = "react-icons/fa"
    tag = "FaOpencart"


class FaOpenid(rx.Component):
    library = "react-icons/fa"
    tag = "FaOpenid"


class FaOpera(rx.Component):
    library = "react-icons/fa"
    tag = "FaOpera"


class FaOptinMonster(rx.Component):
    library = "react-icons/fa"
    tag = "FaOptinMonster"


class FaOrcid(rx.Component):
    library = "react-icons/fa"
    tag = "FaOrcid"


class FaOsi(rx.Component):
    library = "react-icons/fa"
    tag = "FaOsi"


class FaPage4(rx.Component):
    library = "react-icons/fa"
    tag = "FaPage4"


class FaPagelines(rx.Component):
    library = "react-icons/fa"
    tag = "FaPagelines"


class FaPalfed(rx.Component):
    library = "react-icons/fa"
    tag = "FaPalfed"


class FaPatreon(rx.Component):
    library = "react-icons/fa"
    tag = "FaPatreon"


class FaPaypal(rx.Component):
    library = "react-icons/fa"
    tag = "FaPaypal"


class FaPennyArcade(rx.Component):
    library = "react-icons/fa"
    tag = "FaPennyArcade"


class FaPerbyte(rx.Component):
    library = "react-icons/fa"
    tag = "FaPerbyte"


class FaPeriscope(rx.Component):
    library = "react-icons/fa"
    tag = "FaPeriscope"


class FaPhabricator(rx.Component):
    library = "react-icons/fa"
    tag = "FaPhabricator"


class FaPhoenixFramework(rx.Component):
    library = "react-icons/fa"
    tag = "FaPhoenixFramework"


class FaPhoenixSquadron(rx.Component):
    library = "react-icons/fa"
    tag = "FaPhoenixSquadron"


class FaPhp(rx.Component):
    library = "react-icons/fa"
    tag = "FaPhp"


class FaPiedPiperAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaPiedPiperAlt"


class FaPiedPiperHat(rx.Component):
    library = "react-icons/fa"
    tag = "FaPiedPiperHat"


class FaPiedPiperPp(rx.Component):
    library = "react-icons/fa"
    tag = "FaPiedPiperPp"


class FaPiedPiperSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaPiedPiperSquare"


class FaPiedPiper(rx.Component):
    library = "react-icons/fa"
    tag = "FaPiedPiper"


class FaPinterestP(rx.Component):
    library = "react-icons/fa"
    tag = "FaPinterestP"


class FaPinterestSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaPinterestSquare"


class FaPinterest(rx.Component):
    library = "react-icons/fa"
    tag = "FaPinterest"


class FaPlaystation(rx.Component):
    library = "react-icons/fa"
    tag = "FaPlaystation"


class FaProductHunt(rx.Component):
    library = "react-icons/fa"
    tag = "FaProductHunt"


class FaPushed(rx.Component):
    library = "react-icons/fa"
    tag = "FaPushed"


class FaPython(rx.Component):
    library = "react-icons/fa"
    tag = "FaPython"


class FaQq(rx.Component):
    library = "react-icons/fa"
    tag = "FaQq"


class FaQuinscape(rx.Component):
    library = "react-icons/fa"
    tag = "FaQuinscape"


class FaQuora(rx.Component):
    library = "react-icons/fa"
    tag = "FaQuora"


class FaRProject(rx.Component):
    library = "react-icons/fa"
    tag = "FaRProject"


class FaRaspberryPi(rx.Component):
    library = "react-icons/fa"
    tag = "FaRaspberryPi"


class FaRavelry(rx.Component):
    library = "react-icons/fa"
    tag = "FaRavelry"


class FaReact(rx.Component):
    library = "react-icons/fa"
    tag = "FaReact"


class FaReacteurope(rx.Component):
    library = "react-icons/fa"
    tag = "FaReacteurope"


class FaReadme(rx.Component):
    library = "react-icons/fa"
    tag = "FaReadme"


class FaRebel(rx.Component):
    library = "react-icons/fa"
    tag = "FaRebel"


class FaRedRiver(rx.Component):
    library = "react-icons/fa"
    tag = "FaRedRiver"


class FaRedditAlien(rx.Component):
    library = "react-icons/fa"
    tag = "FaRedditAlien"


class FaRedditSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaRedditSquare"


class FaReddit(rx.Component):
    library = "react-icons/fa"
    tag = "FaReddit"


class FaRedhat(rx.Component):
    library = "react-icons/fa"
    tag = "FaRedhat"


class FaRenren(rx.Component):
    library = "react-icons/fa"
    tag = "FaRenren"


class FaReplyd(rx.Component):
    library = "react-icons/fa"
    tag = "FaReplyd"


class FaResearchgate(rx.Component):
    library = "react-icons/fa"
    tag = "FaResearchgate"


class FaResolving(rx.Component):
    library = "react-icons/fa"
    tag = "FaResolving"


class FaRev(rx.Component):
    library = "react-icons/fa"
    tag = "FaRev"


class FaRocketchat(rx.Component):
    library = "react-icons/fa"
    tag = "FaRocketchat"


class FaRockrms(rx.Component):
    library = "react-icons/fa"
    tag = "FaRockrms"


class FaRust(rx.Component):
    library = "react-icons/fa"
    tag = "FaRust"


class FaSafari(rx.Component):
    library = "react-icons/fa"
    tag = "FaSafari"


class FaSalesforce(rx.Component):
    library = "react-icons/fa"
    tag = "FaSalesforce"


class FaSass(rx.Component):
    library = "react-icons/fa"
    tag = "FaSass"


class FaSchlix(rx.Component):
    library = "react-icons/fa"
    tag = "FaSchlix"


class FaScribd(rx.Component):
    library = "react-icons/fa"
    tag = "FaScribd"


class FaSearchengin(rx.Component):
    library = "react-icons/fa"
    tag = "FaSearchengin"


class FaSellcast(rx.Component):
    library = "react-icons/fa"
    tag = "FaSellcast"


class FaSellsy(rx.Component):
    library = "react-icons/fa"
    tag = "FaSellsy"


class FaServicestack(rx.Component):
    library = "react-icons/fa"
    tag = "FaServicestack"


class FaShirtsinbulk(rx.Component):
    library = "react-icons/fa"
    tag = "FaShirtsinbulk"


class FaShopify(rx.Component):
    library = "react-icons/fa"
    tag = "FaShopify"


class FaShopware(rx.Component):
    library = "react-icons/fa"
    tag = "FaShopware"


class FaSimplybuilt(rx.Component):
    library = "react-icons/fa"
    tag = "FaSimplybuilt"


class FaSistrix(rx.Component):
    library = "react-icons/fa"
    tag = "FaSistrix"


class FaSith(rx.Component):
    library = "react-icons/fa"
    tag = "FaSith"


class FaSketch(rx.Component):
    library = "react-icons/fa"
    tag = "FaSketch"


class FaSkyatlas(rx.Component):
    library = "react-icons/fa"
    tag = "FaSkyatlas"


class FaSkype(rx.Component):
    library = "react-icons/fa"
    tag = "FaSkype"


class FaSlackHash(rx.Component):
    library = "react-icons/fa"
    tag = "FaSlackHash"


class FaSlack(rx.Component):
    library = "react-icons/fa"
    tag = "FaSlack"


class FaSlideshare(rx.Component):
    library = "react-icons/fa"
    tag = "FaSlideshare"


class FaSnapchatGhost(rx.Component):
    library = "react-icons/fa"
    tag = "FaSnapchatGhost"


class FaSnapchatSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaSnapchatSquare"


class FaSnapchat(rx.Component):
    library = "react-icons/fa"
    tag = "FaSnapchat"


class FaSoundcloud(rx.Component):
    library = "react-icons/fa"
    tag = "FaSoundcloud"


class FaSourcetree(rx.Component):
    library = "react-icons/fa"
    tag = "FaSourcetree"


class FaSpeakap(rx.Component):
    library = "react-icons/fa"
    tag = "FaSpeakap"


class FaSpeakerDeck(rx.Component):
    library = "react-icons/fa"
    tag = "FaSpeakerDeck"


class FaSpotify(rx.Component):
    library = "react-icons/fa"
    tag = "FaSpotify"


class FaSquarespace(rx.Component):
    library = "react-icons/fa"
    tag = "FaSquarespace"


class FaStackExchange(rx.Component):
    library = "react-icons/fa"
    tag = "FaStackExchange"


class FaStackOverflow(rx.Component):
    library = "react-icons/fa"
    tag = "FaStackOverflow"


class FaStackpath(rx.Component):
    library = "react-icons/fa"
    tag = "FaStackpath"


class FaStaylinked(rx.Component):
    library = "react-icons/fa"
    tag = "FaStaylinked"


class FaSteamSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaSteamSquare"


class FaSteamSymbol(rx.Component):
    library = "react-icons/fa"
    tag = "FaSteamSymbol"


class FaSteam(rx.Component):
    library = "react-icons/fa"
    tag = "FaSteam"


class FaStickerMule(rx.Component):
    library = "react-icons/fa"
    tag = "FaStickerMule"


class FaStrava(rx.Component):
    library = "react-icons/fa"
    tag = "FaStrava"


class FaStripeS(rx.Component):
    library = "react-icons/fa"
    tag = "FaStripeS"


class FaStripe(rx.Component):
    library = "react-icons/fa"
    tag = "FaStripe"


class FaStudiovinari(rx.Component):
    library = "react-icons/fa"
    tag = "FaStudiovinari"


class FaStumbleuponCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaStumbleuponCircle"


class FaStumbleupon(rx.Component):
    library = "react-icons/fa"
    tag = "FaStumbleupon"


class FaSuperpowers(rx.Component):
    library = "react-icons/fa"
    tag = "FaSuperpowers"


class FaSupple(rx.Component):
    library = "react-icons/fa"
    tag = "FaSupple"


class FaSuse(rx.Component):
    library = "react-icons/fa"
    tag = "FaSuse"


class FaSwift(rx.Component):
    library = "react-icons/fa"
    tag = "FaSwift"


class FaSymfony(rx.Component):
    library = "react-icons/fa"
    tag = "FaSymfony"


class FaTeamspeak(rx.Component):
    library = "react-icons/fa"
    tag = "FaTeamspeak"


class FaTelegramPlane(rx.Component):
    library = "react-icons/fa"
    tag = "FaTelegramPlane"


class FaTelegram(rx.Component):
    library = "react-icons/fa"
    tag = "FaTelegram"


class FaTencentWeibo(rx.Component):
    library = "react-icons/fa"
    tag = "FaTencentWeibo"


class FaTheRedYeti(rx.Component):
    library = "react-icons/fa"
    tag = "FaTheRedYeti"


class FaThemeco(rx.Component):
    library = "react-icons/fa"
    tag = "FaThemeco"


class FaThemeisle(rx.Component):
    library = "react-icons/fa"
    tag = "FaThemeisle"


class FaThinkPeaks(rx.Component):
    library = "react-icons/fa"
    tag = "FaThinkPeaks"


class FaTiktok(rx.Component):
    library = "react-icons/fa"
    tag = "FaTiktok"


class FaTradeFederation(rx.Component):
    library = "react-icons/fa"
    tag = "FaTradeFederation"


class FaTrello(rx.Component):
    library = "react-icons/fa"
    tag = "FaTrello"


class FaTripadvisor(rx.Component):
    library = "react-icons/fa"
    tag = "FaTripadvisor"


class FaTumblrSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaTumblrSquare"


class FaTumblr(rx.Component):
    library = "react-icons/fa"
    tag = "FaTumblr"


class FaTwitch(rx.Component):
    library = "react-icons/fa"
    tag = "FaTwitch"


class FaTwitterSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaTwitterSquare"


class FaTwitter(rx.Component):
    library = "react-icons/fa"
    tag = "FaTwitter"


class FaTypo3(rx.Component):
    library = "react-icons/fa"
    tag = "FaTypo3"


class FaUber(rx.Component):
    library = "react-icons/fa"
    tag = "FaUber"


class FaUbuntu(rx.Component):
    library = "react-icons/fa"
    tag = "FaUbuntu"


class FaUikit(rx.Component):
    library = "react-icons/fa"
    tag = "FaUikit"


class FaUmbraco(rx.Component):
    library = "react-icons/fa"
    tag = "FaUmbraco"


class FaUncharted(rx.Component):
    library = "react-icons/fa"
    tag = "FaUncharted"


class FaUniregistry(rx.Component):
    library = "react-icons/fa"
    tag = "FaUniregistry"


class FaUnity(rx.Component):
    library = "react-icons/fa"
    tag = "FaUnity"


class FaUnsplash(rx.Component):
    library = "react-icons/fa"
    tag = "FaUnsplash"


class FaUntappd(rx.Component):
    library = "react-icons/fa"
    tag = "FaUntappd"


class FaUps(rx.Component):
    library = "react-icons/fa"
    tag = "FaUps"


class FaUsb(rx.Component):
    library = "react-icons/fa"
    tag = "FaUsb"


class FaUsps(rx.Component):
    library = "react-icons/fa"
    tag = "FaUsps"


class FaUssunnah(rx.Component):
    library = "react-icons/fa"
    tag = "FaUssunnah"


class FaVaadin(rx.Component):
    library = "react-icons/fa"
    tag = "FaVaadin"


class FaViacoin(rx.Component):
    library = "react-icons/fa"
    tag = "FaViacoin"


class FaViadeoSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaViadeoSquare"


class FaViadeo(rx.Component):
    library = "react-icons/fa"
    tag = "FaViadeo"


class FaViber(rx.Component):
    library = "react-icons/fa"
    tag = "FaViber"


class FaVimeoSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaVimeoSquare"


class FaVimeoV(rx.Component):
    library = "react-icons/fa"
    tag = "FaVimeoV"


class FaVimeo(rx.Component):
    library = "react-icons/fa"
    tag = "FaVimeo"


class FaVine(rx.Component):
    library = "react-icons/fa"
    tag = "FaVine"


class FaVk(rx.Component):
    library = "react-icons/fa"
    tag = "FaVk"


class FaVnv(rx.Component):
    library = "react-icons/fa"
    tag = "FaVnv"


class FaVuejs(rx.Component):
    library = "react-icons/fa"
    tag = "FaVuejs"


class FaWatchmanMonitoring(rx.Component):
    library = "react-icons/fa"
    tag = "FaWatchmanMonitoring"


class FaWaze(rx.Component):
    library = "react-icons/fa"
    tag = "FaWaze"


class FaWeebly(rx.Component):
    library = "react-icons/fa"
    tag = "FaWeebly"


class FaWeibo(rx.Component):
    library = "react-icons/fa"
    tag = "FaWeibo"


class FaWeixin(rx.Component):
    library = "react-icons/fa"
    tag = "FaWeixin"


class FaWhatsappSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaWhatsappSquare"


class FaWhatsapp(rx.Component):
    library = "react-icons/fa"
    tag = "FaWhatsapp"


class FaWhmcs(rx.Component):
    library = "react-icons/fa"
    tag = "FaWhmcs"


class FaWikipediaW(rx.Component):
    library = "react-icons/fa"
    tag = "FaWikipediaW"


class FaWindows(rx.Component):
    library = "react-icons/fa"
    tag = "FaWindows"


class FaWix(rx.Component):
    library = "react-icons/fa"
    tag = "FaWix"


class FaWizardsOfTheCoast(rx.Component):
    library = "react-icons/fa"
    tag = "FaWizardsOfTheCoast"


class FaWodu(rx.Component):
    library = "react-icons/fa"
    tag = "FaWodu"


class FaWolfPackBattalion(rx.Component):
    library = "react-icons/fa"
    tag = "FaWolfPackBattalion"


class FaWordpressSimple(rx.Component):
    library = "react-icons/fa"
    tag = "FaWordpressSimple"


class FaWordpress(rx.Component):
    library = "react-icons/fa"
    tag = "FaWordpress"


class FaWpbeginner(rx.Component):
    library = "react-icons/fa"
    tag = "FaWpbeginner"


class FaWpexplorer(rx.Component):
    library = "react-icons/fa"
    tag = "FaWpexplorer"


class FaWpforms(rx.Component):
    library = "react-icons/fa"
    tag = "FaWpforms"


class FaWpressr(rx.Component):
    library = "react-icons/fa"
    tag = "FaWpressr"


class FaXbox(rx.Component):
    library = "react-icons/fa"
    tag = "FaXbox"


class FaXingSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaXingSquare"


class FaXing(rx.Component):
    library = "react-icons/fa"
    tag = "FaXing"


class FaYCombinator(rx.Component):
    library = "react-icons/fa"
    tag = "FaYCombinator"


class FaYahoo(rx.Component):
    library = "react-icons/fa"
    tag = "FaYahoo"


class FaYammer(rx.Component):
    library = "react-icons/fa"
    tag = "FaYammer"


class FaYandexInternational(rx.Component):
    library = "react-icons/fa"
    tag = "FaYandexInternational"


class FaYandex(rx.Component):
    library = "react-icons/fa"
    tag = "FaYandex"


class FaYarn(rx.Component):
    library = "react-icons/fa"
    tag = "FaYarn"


class FaYelp(rx.Component):
    library = "react-icons/fa"
    tag = "FaYelp"


class FaYoast(rx.Component):
    library = "react-icons/fa"
    tag = "FaYoast"


class FaYoutubeSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaYoutubeSquare"


class FaYoutube(rx.Component):
    library = "react-icons/fa"
    tag = "FaYoutube"


class FaZhihu(rx.Component):
    library = "react-icons/fa"
    tag = "FaZhihu"


class FaAd(rx.Component):
    library = "react-icons/fa"
    tag = "FaAd"


class FaAddressBook(rx.Component):
    library = "react-icons/fa"
    tag = "FaAddressBook"


class FaAddressCard(rx.Component):
    library = "react-icons/fa"
    tag = "FaAddressCard"


class FaAdjust(rx.Component):
    library = "react-icons/fa"
    tag = "FaAdjust"


class FaAirFreshener(rx.Component):
    library = "react-icons/fa"
    tag = "FaAirFreshener"


class FaAlignCenter(rx.Component):
    library = "react-icons/fa"
    tag = "FaAlignCenter"


class FaAlignJustify(rx.Component):
    library = "react-icons/fa"
    tag = "FaAlignJustify"


class FaAlignLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaAlignLeft"


class FaAlignRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaAlignRight"


class FaAllergies(rx.Component):
    library = "react-icons/fa"
    tag = "FaAllergies"


class FaAmbulance(rx.Component):
    library = "react-icons/fa"
    tag = "FaAmbulance"


class FaAmericanSignLanguageInterpreting(rx.Component):
    library = "react-icons/fa"
    tag = "FaAmericanSignLanguageInterpreting"


class FaAnchor(rx.Component):
    library = "react-icons/fa"
    tag = "FaAnchor"


class FaAngleDoubleDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaAngleDoubleDown"


class FaAngleDoubleLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaAngleDoubleLeft"


class FaAngleDoubleRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaAngleDoubleRight"


class FaAngleDoubleUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaAngleDoubleUp"


class FaAngleDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaAngleDown"


class FaAngleLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaAngleLeft"


class FaAngleRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaAngleRight"


class FaAngleUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaAngleUp"


class FaAngry(rx.Component):
    library = "react-icons/fa"
    tag = "FaAngry"


class FaAnkh(rx.Component):
    library = "react-icons/fa"
    tag = "FaAnkh"


class FaAppleAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaAppleAlt"


class FaArchive(rx.Component):
    library = "react-icons/fa"
    tag = "FaArchive"


class FaArchway(rx.Component):
    library = "react-icons/fa"
    tag = "FaArchway"


class FaArrowAltCircleDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowAltCircleDown"


class FaArrowAltCircleLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowAltCircleLeft"


class FaArrowAltCircleRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowAltCircleRight"


class FaArrowAltCircleUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowAltCircleUp"


class FaArrowCircleDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowCircleDown"


class FaArrowCircleLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowCircleLeft"


class FaArrowCircleRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowCircleRight"


class FaArrowCircleUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowCircleUp"


class FaArrowDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowDown"


class FaArrowLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowLeft"


class FaArrowRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowRight"


class FaArrowUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowUp"


class FaArrowsAltH(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowsAltH"


class FaArrowsAltV(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowsAltV"


class FaArrowsAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaArrowsAlt"


class FaAssistiveListeningSystems(rx.Component):
    library = "react-icons/fa"
    tag = "FaAssistiveListeningSystems"


class FaAsterisk(rx.Component):
    library = "react-icons/fa"
    tag = "FaAsterisk"


class FaAt(rx.Component):
    library = "react-icons/fa"
    tag = "FaAt"


class FaAtlas(rx.Component):
    library = "react-icons/fa"
    tag = "FaAtlas"


class FaAtom(rx.Component):
    library = "react-icons/fa"
    tag = "FaAtom"


class FaAudioDescription(rx.Component):
    library = "react-icons/fa"
    tag = "FaAudioDescription"


class FaAward(rx.Component):
    library = "react-icons/fa"
    tag = "FaAward"


class FaBabyCarriage(rx.Component):
    library = "react-icons/fa"
    tag = "FaBabyCarriage"


class FaBaby(rx.Component):
    library = "react-icons/fa"
    tag = "FaBaby"


class FaBackspace(rx.Component):
    library = "react-icons/fa"
    tag = "FaBackspace"


class FaBackward(rx.Component):
    library = "react-icons/fa"
    tag = "FaBackward"


class FaBacon(rx.Component):
    library = "react-icons/fa"
    tag = "FaBacon"


class FaBacteria(rx.Component):
    library = "react-icons/fa"
    tag = "FaBacteria"


class FaBacterium(rx.Component):
    library = "react-icons/fa"
    tag = "FaBacterium"


class FaBahai(rx.Component):
    library = "react-icons/fa"
    tag = "FaBahai"


class FaBalanceScaleLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaBalanceScaleLeft"


class FaBalanceScaleRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaBalanceScaleRight"


class FaBalanceScale(rx.Component):
    library = "react-icons/fa"
    tag = "FaBalanceScale"


class FaBan(rx.Component):
    library = "react-icons/fa"
    tag = "FaBan"


class FaBandAid(rx.Component):
    library = "react-icons/fa"
    tag = "FaBandAid"


class FaBarcode(rx.Component):
    library = "react-icons/fa"
    tag = "FaBarcode"


class FaBars(rx.Component):
    library = "react-icons/fa"
    tag = "FaBars"


class FaBaseballBall(rx.Component):
    library = "react-icons/fa"
    tag = "FaBaseballBall"


class FaBasketballBall(rx.Component):
    library = "react-icons/fa"
    tag = "FaBasketballBall"


class FaBath(rx.Component):
    library = "react-icons/fa"
    tag = "FaBath"


class FaBatteryEmpty(rx.Component):
    library = "react-icons/fa"
    tag = "FaBatteryEmpty"


class FaBatteryFull(rx.Component):
    library = "react-icons/fa"
    tag = "FaBatteryFull"


class FaBatteryHalf(rx.Component):
    library = "react-icons/fa"
    tag = "FaBatteryHalf"


class FaBatteryQuarter(rx.Component):
    library = "react-icons/fa"
    tag = "FaBatteryQuarter"


class FaBatteryThreeQuarters(rx.Component):
    library = "react-icons/fa"
    tag = "FaBatteryThreeQuarters"


class FaBed(rx.Component):
    library = "react-icons/fa"
    tag = "FaBed"


class FaBeer(rx.Component):
    library = "react-icons/fa"
    tag = "FaBeer"


class FaBellSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaBellSlash"


class FaBell(rx.Component):
    library = "react-icons/fa"
    tag = "FaBell"


class FaBezierCurve(rx.Component):
    library = "react-icons/fa"
    tag = "FaBezierCurve"


class FaBible(rx.Component):
    library = "react-icons/fa"
    tag = "FaBible"


class FaBicycle(rx.Component):
    library = "react-icons/fa"
    tag = "FaBicycle"


class FaBiking(rx.Component):
    library = "react-icons/fa"
    tag = "FaBiking"


class FaBinoculars(rx.Component):
    library = "react-icons/fa"
    tag = "FaBinoculars"


class FaBiohazard(rx.Component):
    library = "react-icons/fa"
    tag = "FaBiohazard"


class FaBirthdayCake(rx.Component):
    library = "react-icons/fa"
    tag = "FaBirthdayCake"


class FaBlenderPhone(rx.Component):
    library = "react-icons/fa"
    tag = "FaBlenderPhone"


class FaBlender(rx.Component):
    library = "react-icons/fa"
    tag = "FaBlender"


class FaBlind(rx.Component):
    library = "react-icons/fa"
    tag = "FaBlind"


class FaBlog(rx.Component):
    library = "react-icons/fa"
    tag = "FaBlog"


class FaBold(rx.Component):
    library = "react-icons/fa"
    tag = "FaBold"


class FaBolt(rx.Component):
    library = "react-icons/fa"
    tag = "FaBolt"


class FaBomb(rx.Component):
    library = "react-icons/fa"
    tag = "FaBomb"


class FaBone(rx.Component):
    library = "react-icons/fa"
    tag = "FaBone"


class FaBong(rx.Component):
    library = "react-icons/fa"
    tag = "FaBong"


class FaBookDead(rx.Component):
    library = "react-icons/fa"
    tag = "FaBookDead"


class FaBookMedical(rx.Component):
    library = "react-icons/fa"
    tag = "FaBookMedical"


class FaBookOpen(rx.Component):
    library = "react-icons/fa"
    tag = "FaBookOpen"


class FaBookReader(rx.Component):
    library = "react-icons/fa"
    tag = "FaBookReader"


class FaBook(rx.Component):
    library = "react-icons/fa"
    tag = "FaBook"


class FaBookmark(rx.Component):
    library = "react-icons/fa"
    tag = "FaBookmark"


class FaBorderAll(rx.Component):
    library = "react-icons/fa"
    tag = "FaBorderAll"


class FaBorderNone(rx.Component):
    library = "react-icons/fa"
    tag = "FaBorderNone"


class FaBorderStyle(rx.Component):
    library = "react-icons/fa"
    tag = "FaBorderStyle"


class FaBowlingBall(rx.Component):
    library = "react-icons/fa"
    tag = "FaBowlingBall"


class FaBoxOpen(rx.Component):
    library = "react-icons/fa"
    tag = "FaBoxOpen"


class FaBoxTissue(rx.Component):
    library = "react-icons/fa"
    tag = "FaBoxTissue"


class FaBox(rx.Component):
    library = "react-icons/fa"
    tag = "FaBox"


class FaBoxes(rx.Component):
    library = "react-icons/fa"
    tag = "FaBoxes"


class FaBraille(rx.Component):
    library = "react-icons/fa"
    tag = "FaBraille"


class FaBrain(rx.Component):
    library = "react-icons/fa"
    tag = "FaBrain"


class FaBreadSlice(rx.Component):
    library = "react-icons/fa"
    tag = "FaBreadSlice"


class FaBriefcaseMedical(rx.Component):
    library = "react-icons/fa"
    tag = "FaBriefcaseMedical"


class FaBriefcase(rx.Component):
    library = "react-icons/fa"
    tag = "FaBriefcase"


class FaBroadcastTower(rx.Component):
    library = "react-icons/fa"
    tag = "FaBroadcastTower"


class FaBroom(rx.Component):
    library = "react-icons/fa"
    tag = "FaBroom"


class FaBrush(rx.Component):
    library = "react-icons/fa"
    tag = "FaBrush"


class FaBug(rx.Component):
    library = "react-icons/fa"
    tag = "FaBug"


class FaBuilding(rx.Component):
    library = "react-icons/fa"
    tag = "FaBuilding"


class FaBullhorn(rx.Component):
    library = "react-icons/fa"
    tag = "FaBullhorn"


class FaBullseye(rx.Component):
    library = "react-icons/fa"
    tag = "FaBullseye"


class FaBurn(rx.Component):
    library = "react-icons/fa"
    tag = "FaBurn"


class FaBusAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaBusAlt"


class FaBus(rx.Component):
    library = "react-icons/fa"
    tag = "FaBus"


class FaBusinessTime(rx.Component):
    library = "react-icons/fa"
    tag = "FaBusinessTime"


class FaCalculator(rx.Component):
    library = "react-icons/fa"
    tag = "FaCalculator"


class FaCalendarAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaCalendarAlt"


class FaCalendarCheck(rx.Component):
    library = "react-icons/fa"
    tag = "FaCalendarCheck"


class FaCalendarDay(rx.Component):
    library = "react-icons/fa"
    tag = "FaCalendarDay"


class FaCalendarMinus(rx.Component):
    library = "react-icons/fa"
    tag = "FaCalendarMinus"


class FaCalendarPlus(rx.Component):
    library = "react-icons/fa"
    tag = "FaCalendarPlus"


class FaCalendarTimes(rx.Component):
    library = "react-icons/fa"
    tag = "FaCalendarTimes"


class FaCalendarWeek(rx.Component):
    library = "react-icons/fa"
    tag = "FaCalendarWeek"


class FaCalendar(rx.Component):
    library = "react-icons/fa"
    tag = "FaCalendar"


class FaCameraRetro(rx.Component):
    library = "react-icons/fa"
    tag = "FaCameraRetro"


class FaCamera(rx.Component):
    library = "react-icons/fa"
    tag = "FaCamera"


class FaCampground(rx.Component):
    library = "react-icons/fa"
    tag = "FaCampground"


class FaCandyCane(rx.Component):
    library = "react-icons/fa"
    tag = "FaCandyCane"


class FaCannabis(rx.Component):
    library = "react-icons/fa"
    tag = "FaCannabis"


class FaCapsules(rx.Component):
    library = "react-icons/fa"
    tag = "FaCapsules"


class FaCarAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaCarAlt"


class FaCarBattery(rx.Component):
    library = "react-icons/fa"
    tag = "FaCarBattery"


class FaCarCrash(rx.Component):
    library = "react-icons/fa"
    tag = "FaCarCrash"


class FaCarSide(rx.Component):
    library = "react-icons/fa"
    tag = "FaCarSide"


class FaCar(rx.Component):
    library = "react-icons/fa"
    tag = "FaCar"


class FaCaravan(rx.Component):
    library = "react-icons/fa"
    tag = "FaCaravan"


class FaCaretDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaCaretDown"


class FaCaretLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaCaretLeft"


class FaCaretRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaCaretRight"


class FaCaretSquareDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaCaretSquareDown"


class FaCaretSquareLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaCaretSquareLeft"


class FaCaretSquareRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaCaretSquareRight"


class FaCaretSquareUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaCaretSquareUp"


class FaCaretUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaCaretUp"


class FaCarrot(rx.Component):
    library = "react-icons/fa"
    tag = "FaCarrot"


class FaCartArrowDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaCartArrowDown"


class FaCartPlus(rx.Component):
    library = "react-icons/fa"
    tag = "FaCartPlus"


class FaCashRegister(rx.Component):
    library = "react-icons/fa"
    tag = "FaCashRegister"


class FaCat(rx.Component):
    library = "react-icons/fa"
    tag = "FaCat"


class FaCertificate(rx.Component):
    library = "react-icons/fa"
    tag = "FaCertificate"


class FaChair(rx.Component):
    library = "react-icons/fa"
    tag = "FaChair"


class FaChalkboardTeacher(rx.Component):
    library = "react-icons/fa"
    tag = "FaChalkboardTeacher"


class FaChalkboard(rx.Component):
    library = "react-icons/fa"
    tag = "FaChalkboard"


class FaChargingStation(rx.Component):
    library = "react-icons/fa"
    tag = "FaChargingStation"


class FaChartArea(rx.Component):
    library = "react-icons/fa"
    tag = "FaChartArea"


class FaChartBar(rx.Component):
    library = "react-icons/fa"
    tag = "FaChartBar"


class FaChartLine(rx.Component):
    library = "react-icons/fa"
    tag = "FaChartLine"


class FaChartPie(rx.Component):
    library = "react-icons/fa"
    tag = "FaChartPie"


class FaCheckCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaCheckCircle"


class FaCheckDouble(rx.Component):
    library = "react-icons/fa"
    tag = "FaCheckDouble"


class FaCheckSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaCheckSquare"


class FaCheck(rx.Component):
    library = "react-icons/fa"
    tag = "FaCheck"


class FaCheese(rx.Component):
    library = "react-icons/fa"
    tag = "FaCheese"


class FaChessBishop(rx.Component):
    library = "react-icons/fa"
    tag = "FaChessBishop"


class FaChessBoard(rx.Component):
    library = "react-icons/fa"
    tag = "FaChessBoard"


class FaChessKing(rx.Component):
    library = "react-icons/fa"
    tag = "FaChessKing"


class FaChessKnight(rx.Component):
    library = "react-icons/fa"
    tag = "FaChessKnight"


class FaChessPawn(rx.Component):
    library = "react-icons/fa"
    tag = "FaChessPawn"


class FaChessQueen(rx.Component):
    library = "react-icons/fa"
    tag = "FaChessQueen"


class FaChessRook(rx.Component):
    library = "react-icons/fa"
    tag = "FaChessRook"


class FaChess(rx.Component):
    library = "react-icons/fa"
    tag = "FaChess"


class FaChevronCircleDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaChevronCircleDown"


class FaChevronCircleLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaChevronCircleLeft"


class FaChevronCircleRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaChevronCircleRight"


class FaChevronCircleUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaChevronCircleUp"


class FaChevronDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaChevronDown"


class FaChevronLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaChevronLeft"


class FaChevronRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaChevronRight"


class FaChevronUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaChevronUp"


class FaChild(rx.Component):
    library = "react-icons/fa"
    tag = "FaChild"


class FaChurch(rx.Component):
    library = "react-icons/fa"
    tag = "FaChurch"


class FaCircleNotch(rx.Component):
    library = "react-icons/fa"
    tag = "FaCircleNotch"


class FaCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaCircle"


class FaCity(rx.Component):
    library = "react-icons/fa"
    tag = "FaCity"


class FaClinicMedical(rx.Component):
    library = "react-icons/fa"
    tag = "FaClinicMedical"


class FaClipboardCheck(rx.Component):
    library = "react-icons/fa"
    tag = "FaClipboardCheck"


class FaClipboardList(rx.Component):
    library = "react-icons/fa"
    tag = "FaClipboardList"


class FaClipboard(rx.Component):
    library = "react-icons/fa"
    tag = "FaClipboard"


class FaClock(rx.Component):
    library = "react-icons/fa"
    tag = "FaClock"


class FaClone(rx.Component):
    library = "react-icons/fa"
    tag = "FaClone"


class FaClosedCaptioning(rx.Component):
    library = "react-icons/fa"
    tag = "FaClosedCaptioning"


class FaCloudDownloadAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloudDownloadAlt"


class FaCloudMeatball(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloudMeatball"


class FaCloudMoonRain(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloudMoonRain"


class FaCloudMoon(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloudMoon"


class FaCloudRain(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloudRain"


class FaCloudShowersHeavy(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloudShowersHeavy"


class FaCloudSunRain(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloudSunRain"


class FaCloudSun(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloudSun"


class FaCloudUploadAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloudUploadAlt"


class FaCloud(rx.Component):
    library = "react-icons/fa"
    tag = "FaCloud"


class FaCocktail(rx.Component):
    library = "react-icons/fa"
    tag = "FaCocktail"


class FaCodeBranch(rx.Component):
    library = "react-icons/fa"
    tag = "FaCodeBranch"


class FaCode(rx.Component):
    library = "react-icons/fa"
    tag = "FaCode"


class FaCoffee(rx.Component):
    library = "react-icons/fa"
    tag = "FaCoffee"


class FaCog(rx.Component):
    library = "react-icons/fa"
    tag = "FaCog"


class FaCogs(rx.Component):
    library = "react-icons/fa"
    tag = "FaCogs"


class FaCoins(rx.Component):
    library = "react-icons/fa"
    tag = "FaCoins"


class FaColumns(rx.Component):
    library = "react-icons/fa"
    tag = "FaColumns"


class FaCommentAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaCommentAlt"


class FaCommentDollar(rx.Component):
    library = "react-icons/fa"
    tag = "FaCommentDollar"


class FaCommentDots(rx.Component):
    library = "react-icons/fa"
    tag = "FaCommentDots"


class FaCommentMedical(rx.Component):
    library = "react-icons/fa"
    tag = "FaCommentMedical"


class FaCommentSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaCommentSlash"


class FaComment(rx.Component):
    library = "react-icons/fa"
    tag = "FaComment"


class FaCommentsDollar(rx.Component):
    library = "react-icons/fa"
    tag = "FaCommentsDollar"


class FaComments(rx.Component):
    library = "react-icons/fa"
    tag = "FaComments"


class FaCompactDisc(rx.Component):
    library = "react-icons/fa"
    tag = "FaCompactDisc"


class FaCompass(rx.Component):
    library = "react-icons/fa"
    tag = "FaCompass"


class FaCompressAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaCompressAlt"


class FaCompressArrowsAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaCompressArrowsAlt"


class FaCompress(rx.Component):
    library = "react-icons/fa"
    tag = "FaCompress"


class FaConciergeBell(rx.Component):
    library = "react-icons/fa"
    tag = "FaConciergeBell"


class FaCookieBite(rx.Component):
    library = "react-icons/fa"
    tag = "FaCookieBite"


class FaCookie(rx.Component):
    library = "react-icons/fa"
    tag = "FaCookie"


class FaCopy(rx.Component):
    library = "react-icons/fa"
    tag = "FaCopy"


class FaCopyright(rx.Component):
    library = "react-icons/fa"
    tag = "FaCopyright"


class FaCouch(rx.Component):
    library = "react-icons/fa"
    tag = "FaCouch"


class FaCreditCard(rx.Component):
    library = "react-icons/fa"
    tag = "FaCreditCard"


class FaCropAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaCropAlt"


class FaCrop(rx.Component):
    library = "react-icons/fa"
    tag = "FaCrop"


class FaCross(rx.Component):
    library = "react-icons/fa"
    tag = "FaCross"


class FaCrosshairs(rx.Component):
    library = "react-icons/fa"
    tag = "FaCrosshairs"


class FaCrow(rx.Component):
    library = "react-icons/fa"
    tag = "FaCrow"


class FaCrown(rx.Component):
    library = "react-icons/fa"
    tag = "FaCrown"


class FaCrutch(rx.Component):
    library = "react-icons/fa"
    tag = "FaCrutch"


class FaCube(rx.Component):
    library = "react-icons/fa"
    tag = "FaCube"


class FaCubes(rx.Component):
    library = "react-icons/fa"
    tag = "FaCubes"


class FaCut(rx.Component):
    library = "react-icons/fa"
    tag = "FaCut"


class FaDatabase(rx.Component):
    library = "react-icons/fa"
    tag = "FaDatabase"


class FaDeaf(rx.Component):
    library = "react-icons/fa"
    tag = "FaDeaf"


class FaDemocrat(rx.Component):
    library = "react-icons/fa"
    tag = "FaDemocrat"


class FaDesktop(rx.Component):
    library = "react-icons/fa"
    tag = "FaDesktop"


class FaDharmachakra(rx.Component):
    library = "react-icons/fa"
    tag = "FaDharmachakra"


class FaDiagnoses(rx.Component):
    library = "react-icons/fa"
    tag = "FaDiagnoses"


class FaDiceD20(rx.Component):
    library = "react-icons/fa"
    tag = "FaDiceD20"


class FaDiceD6(rx.Component):
    library = "react-icons/fa"
    tag = "FaDiceD6"


class FaDiceFive(rx.Component):
    library = "react-icons/fa"
    tag = "FaDiceFive"


class FaDiceFour(rx.Component):
    library = "react-icons/fa"
    tag = "FaDiceFour"


class FaDiceOne(rx.Component):
    library = "react-icons/fa"
    tag = "FaDiceOne"


class FaDiceSix(rx.Component):
    library = "react-icons/fa"
    tag = "FaDiceSix"


class FaDiceThree(rx.Component):
    library = "react-icons/fa"
    tag = "FaDiceThree"


class FaDiceTwo(rx.Component):
    library = "react-icons/fa"
    tag = "FaDiceTwo"


class FaDice(rx.Component):
    library = "react-icons/fa"
    tag = "FaDice"


class FaDigitalTachograph(rx.Component):
    library = "react-icons/fa"
    tag = "FaDigitalTachograph"


class FaDirections(rx.Component):
    library = "react-icons/fa"
    tag = "FaDirections"


class FaDisease(rx.Component):
    library = "react-icons/fa"
    tag = "FaDisease"


class FaDivide(rx.Component):
    library = "react-icons/fa"
    tag = "FaDivide"


class FaDizzy(rx.Component):
    library = "react-icons/fa"
    tag = "FaDizzy"


class FaDna(rx.Component):
    library = "react-icons/fa"
    tag = "FaDna"


class FaDog(rx.Component):
    library = "react-icons/fa"
    tag = "FaDog"


class FaDollarSign(rx.Component):
    library = "react-icons/fa"
    tag = "FaDollarSign"


class FaDollyFlatbed(rx.Component):
    library = "react-icons/fa"
    tag = "FaDollyFlatbed"


class FaDolly(rx.Component):
    library = "react-icons/fa"
    tag = "FaDolly"


class FaDonate(rx.Component):
    library = "react-icons/fa"
    tag = "FaDonate"


class FaDoorClosed(rx.Component):
    library = "react-icons/fa"
    tag = "FaDoorClosed"


class FaDoorOpen(rx.Component):
    library = "react-icons/fa"
    tag = "FaDoorOpen"


class FaDotCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaDotCircle"


class FaDove(rx.Component):
    library = "react-icons/fa"
    tag = "FaDove"


class FaDownload(rx.Component):
    library = "react-icons/fa"
    tag = "FaDownload"


class FaDraftingCompass(rx.Component):
    library = "react-icons/fa"
    tag = "FaDraftingCompass"


class FaDragon(rx.Component):
    library = "react-icons/fa"
    tag = "FaDragon"


class FaDrawPolygon(rx.Component):
    library = "react-icons/fa"
    tag = "FaDrawPolygon"


class FaDrumSteelpan(rx.Component):
    library = "react-icons/fa"
    tag = "FaDrumSteelpan"


class FaDrum(rx.Component):
    library = "react-icons/fa"
    tag = "FaDrum"


class FaDrumstickBite(rx.Component):
    library = "react-icons/fa"
    tag = "FaDrumstickBite"


class FaDumbbell(rx.Component):
    library = "react-icons/fa"
    tag = "FaDumbbell"


class FaDumpsterFire(rx.Component):
    library = "react-icons/fa"
    tag = "FaDumpsterFire"


class FaDumpster(rx.Component):
    library = "react-icons/fa"
    tag = "FaDumpster"


class FaDungeon(rx.Component):
    library = "react-icons/fa"
    tag = "FaDungeon"


class FaEdit(rx.Component):
    library = "react-icons/fa"
    tag = "FaEdit"


class FaEgg(rx.Component):
    library = "react-icons/fa"
    tag = "FaEgg"


class FaEject(rx.Component):
    library = "react-icons/fa"
    tag = "FaEject"


class FaEllipsisH(rx.Component):
    library = "react-icons/fa"
    tag = "FaEllipsisH"


class FaEllipsisV(rx.Component):
    library = "react-icons/fa"
    tag = "FaEllipsisV"


class FaEnvelopeOpenText(rx.Component):
    library = "react-icons/fa"
    tag = "FaEnvelopeOpenText"


class FaEnvelopeOpen(rx.Component):
    library = "react-icons/fa"
    tag = "FaEnvelopeOpen"


class FaEnvelopeSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaEnvelopeSquare"


class FaEnvelope(rx.Component):
    library = "react-icons/fa"
    tag = "FaEnvelope"


class FaEquals(rx.Component):
    library = "react-icons/fa"
    tag = "FaEquals"


class FaEraser(rx.Component):
    library = "react-icons/fa"
    tag = "FaEraser"


class FaEthernet(rx.Component):
    library = "react-icons/fa"
    tag = "FaEthernet"


class FaEuroSign(rx.Component):
    library = "react-icons/fa"
    tag = "FaEuroSign"


class FaExchangeAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaExchangeAlt"


class FaExclamationCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaExclamationCircle"


class FaExclamationTriangle(rx.Component):
    library = "react-icons/fa"
    tag = "FaExclamationTriangle"


class FaExclamation(rx.Component):
    library = "react-icons/fa"
    tag = "FaExclamation"


class FaExpandAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaExpandAlt"


class FaExpandArrowsAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaExpandArrowsAlt"


class FaExpand(rx.Component):
    library = "react-icons/fa"
    tag = "FaExpand"


class FaExternalLinkAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaExternalLinkAlt"


class FaExternalLinkSquareAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaExternalLinkSquareAlt"


class FaEyeDropper(rx.Component):
    library = "react-icons/fa"
    tag = "FaEyeDropper"


class FaEyeSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaEyeSlash"


class FaEye(rx.Component):
    library = "react-icons/fa"
    tag = "FaEye"


class FaFan(rx.Component):
    library = "react-icons/fa"
    tag = "FaFan"


class FaFastBackward(rx.Component):
    library = "react-icons/fa"
    tag = "FaFastBackward"


class FaFastForward(rx.Component):
    library = "react-icons/fa"
    tag = "FaFastForward"


class FaFaucet(rx.Component):
    library = "react-icons/fa"
    tag = "FaFaucet"


class FaFax(rx.Component):
    library = "react-icons/fa"
    tag = "FaFax"


class FaFeatherAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaFeatherAlt"


class FaFeather(rx.Component):
    library = "react-icons/fa"
    tag = "FaFeather"


class FaFemale(rx.Component):
    library = "react-icons/fa"
    tag = "FaFemale"


class FaFighterJet(rx.Component):
    library = "react-icons/fa"
    tag = "FaFighterJet"


class FaFileAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileAlt"


class FaFileArchive(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileArchive"


class FaFileAudio(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileAudio"


class FaFileCode(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileCode"


class FaFileContract(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileContract"


class FaFileCsv(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileCsv"


class FaFileDownload(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileDownload"


class FaFileExcel(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileExcel"


class FaFileExport(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileExport"


class FaFileImage(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileImage"


class FaFileImport(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileImport"


class FaFileInvoiceDollar(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileInvoiceDollar"


class FaFileInvoice(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileInvoice"


class FaFileMedicalAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileMedicalAlt"


class FaFileMedical(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileMedical"


class FaFilePdf(rx.Component):
    library = "react-icons/fa"
    tag = "FaFilePdf"


class FaFilePowerpoint(rx.Component):
    library = "react-icons/fa"
    tag = "FaFilePowerpoint"


class FaFilePrescription(rx.Component):
    library = "react-icons/fa"
    tag = "FaFilePrescription"


class FaFileSignature(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileSignature"


class FaFileUpload(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileUpload"


class FaFileVideo(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileVideo"


class FaFileWord(rx.Component):
    library = "react-icons/fa"
    tag = "FaFileWord"


class FaFile(rx.Component):
    library = "react-icons/fa"
    tag = "FaFile"


class FaFillDrip(rx.Component):
    library = "react-icons/fa"
    tag = "FaFillDrip"


class FaFill(rx.Component):
    library = "react-icons/fa"
    tag = "FaFill"


class FaFilm(rx.Component):
    library = "react-icons/fa"
    tag = "FaFilm"


class FaFilter(rx.Component):
    library = "react-icons/fa"
    tag = "FaFilter"


class FaFingerprint(rx.Component):
    library = "react-icons/fa"
    tag = "FaFingerprint"


class FaFireAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaFireAlt"


class FaFireExtinguisher(rx.Component):
    library = "react-icons/fa"
    tag = "FaFireExtinguisher"


class FaFire(rx.Component):
    library = "react-icons/fa"
    tag = "FaFire"


class FaFirstAid(rx.Component):
    library = "react-icons/fa"
    tag = "FaFirstAid"


class FaFish(rx.Component):
    library = "react-icons/fa"
    tag = "FaFish"


class FaFistRaised(rx.Component):
    library = "react-icons/fa"
    tag = "FaFistRaised"


class FaFlagCheckered(rx.Component):
    library = "react-icons/fa"
    tag = "FaFlagCheckered"


class FaFlagUsa(rx.Component):
    library = "react-icons/fa"
    tag = "FaFlagUsa"


class FaFlag(rx.Component):
    library = "react-icons/fa"
    tag = "FaFlag"


class FaFlask(rx.Component):
    library = "react-icons/fa"
    tag = "FaFlask"


class FaFlushed(rx.Component):
    library = "react-icons/fa"
    tag = "FaFlushed"


class FaFolderMinus(rx.Component):
    library = "react-icons/fa"
    tag = "FaFolderMinus"


class FaFolderOpen(rx.Component):
    library = "react-icons/fa"
    tag = "FaFolderOpen"


class FaFolderPlus(rx.Component):
    library = "react-icons/fa"
    tag = "FaFolderPlus"


class FaFolder(rx.Component):
    library = "react-icons/fa"
    tag = "FaFolder"


class FaFont(rx.Component):
    library = "react-icons/fa"
    tag = "FaFont"


class FaFootballBall(rx.Component):
    library = "react-icons/fa"
    tag = "FaFootballBall"


class FaForward(rx.Component):
    library = "react-icons/fa"
    tag = "FaForward"


class FaFrog(rx.Component):
    library = "react-icons/fa"
    tag = "FaFrog"


class FaFrownOpen(rx.Component):
    library = "react-icons/fa"
    tag = "FaFrownOpen"


class FaFrown(rx.Component):
    library = "react-icons/fa"
    tag = "FaFrown"


class FaFunnelDollar(rx.Component):
    library = "react-icons/fa"
    tag = "FaFunnelDollar"


class FaFutbol(rx.Component):
    library = "react-icons/fa"
    tag = "FaFutbol"


class FaGamepad(rx.Component):
    library = "react-icons/fa"
    tag = "FaGamepad"


class FaGasPump(rx.Component):
    library = "react-icons/fa"
    tag = "FaGasPump"


class FaGavel(rx.Component):
    library = "react-icons/fa"
    tag = "FaGavel"


class FaGem(rx.Component):
    library = "react-icons/fa"
    tag = "FaGem"


class FaGenderless(rx.Component):
    library = "react-icons/fa"
    tag = "FaGenderless"


class FaGhost(rx.Component):
    library = "react-icons/fa"
    tag = "FaGhost"


class FaGift(rx.Component):
    library = "react-icons/fa"
    tag = "FaGift"


class FaGifts(rx.Component):
    library = "react-icons/fa"
    tag = "FaGifts"


class FaGlassCheers(rx.Component):
    library = "react-icons/fa"
    tag = "FaGlassCheers"


class FaGlassMartiniAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaGlassMartiniAlt"


class FaGlassMartini(rx.Component):
    library = "react-icons/fa"
    tag = "FaGlassMartini"


class FaGlassWhiskey(rx.Component):
    library = "react-icons/fa"
    tag = "FaGlassWhiskey"


class FaGlasses(rx.Component):
    library = "react-icons/fa"
    tag = "FaGlasses"


class FaGlobeAfrica(rx.Component):
    library = "react-icons/fa"
    tag = "FaGlobeAfrica"


class FaGlobeAmericas(rx.Component):
    library = "react-icons/fa"
    tag = "FaGlobeAmericas"


class FaGlobeAsia(rx.Component):
    library = "react-icons/fa"
    tag = "FaGlobeAsia"


class FaGlobeEurope(rx.Component):
    library = "react-icons/fa"
    tag = "FaGlobeEurope"


class FaGlobe(rx.Component):
    library = "react-icons/fa"
    tag = "FaGlobe"


class FaGolfBall(rx.Component):
    library = "react-icons/fa"
    tag = "FaGolfBall"


class FaGopuram(rx.Component):
    library = "react-icons/fa"
    tag = "FaGopuram"


class FaGraduationCap(rx.Component):
    library = "react-icons/fa"
    tag = "FaGraduationCap"


class FaGreaterThanEqual(rx.Component):
    library = "react-icons/fa"
    tag = "FaGreaterThanEqual"


class FaGreaterThan(rx.Component):
    library = "react-icons/fa"
    tag = "FaGreaterThan"


class FaGrimace(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrimace"


class FaGrinAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrinAlt"


class FaGrinBeamSweat(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrinBeamSweat"


class FaGrinBeam(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrinBeam"


class FaGrinHearts(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrinHearts"


class FaGrinSquintTears(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrinSquintTears"


class FaGrinSquint(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrinSquint"


class FaGrinStars(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrinStars"


class FaGrinTears(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrinTears"


class FaGrinTongueSquint(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrinTongueSquint"


class FaGrinTongueWink(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrinTongueWink"


class FaGrinTongue(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrinTongue"


class FaGrinWink(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrinWink"


class FaGrin(rx.Component):
    library = "react-icons/fa"
    tag = "FaGrin"


class FaGripHorizontal(rx.Component):
    library = "react-icons/fa"
    tag = "FaGripHorizontal"


class FaGripLinesVertical(rx.Component):
    library = "react-icons/fa"
    tag = "FaGripLinesVertical"


class FaGripLines(rx.Component):
    library = "react-icons/fa"
    tag = "FaGripLines"


class FaGripVertical(rx.Component):
    library = "react-icons/fa"
    tag = "FaGripVertical"


class FaGuitar(rx.Component):
    library = "react-icons/fa"
    tag = "FaGuitar"


class FaHSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaHSquare"


class FaHamburger(rx.Component):
    library = "react-icons/fa"
    tag = "FaHamburger"


class FaHammer(rx.Component):
    library = "react-icons/fa"
    tag = "FaHammer"


class FaHamsa(rx.Component):
    library = "react-icons/fa"
    tag = "FaHamsa"


class FaHandHoldingHeart(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandHoldingHeart"


class FaHandHoldingMedical(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandHoldingMedical"


class FaHandHoldingUsd(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandHoldingUsd"


class FaHandHoldingWater(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandHoldingWater"


class FaHandHolding(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandHolding"


class FaHandLizard(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandLizard"


class FaHandMiddleFinger(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandMiddleFinger"


class FaHandPaper(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandPaper"


class FaHandPeace(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandPeace"


class FaHandPointDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandPointDown"


class FaHandPointLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandPointLeft"


class FaHandPointRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandPointRight"


class FaHandPointUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandPointUp"


class FaHandPointer(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandPointer"


class FaHandRock(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandRock"


class FaHandScissors(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandScissors"


class FaHandSparkles(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandSparkles"


class FaHandSpock(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandSpock"


class FaHandsHelping(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandsHelping"


class FaHandsWash(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandsWash"


class FaHands(rx.Component):
    library = "react-icons/fa"
    tag = "FaHands"


class FaHandshakeAltSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandshakeAltSlash"


class FaHandshakeSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandshakeSlash"


class FaHandshake(rx.Component):
    library = "react-icons/fa"
    tag = "FaHandshake"


class FaHanukiah(rx.Component):
    library = "react-icons/fa"
    tag = "FaHanukiah"


class FaHardHat(rx.Component):
    library = "react-icons/fa"
    tag = "FaHardHat"


class FaHashtag(rx.Component):
    library = "react-icons/fa"
    tag = "FaHashtag"


class FaHatCowboySide(rx.Component):
    library = "react-icons/fa"
    tag = "FaHatCowboySide"


class FaHatCowboy(rx.Component):
    library = "react-icons/fa"
    tag = "FaHatCowboy"


class FaHatWizard(rx.Component):
    library = "react-icons/fa"
    tag = "FaHatWizard"


class FaHdd(rx.Component):
    library = "react-icons/fa"
    tag = "FaHdd"


class FaHeadSideCoughSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaHeadSideCoughSlash"


class FaHeadSideCough(rx.Component):
    library = "react-icons/fa"
    tag = "FaHeadSideCough"


class FaHeadSideMask(rx.Component):
    library = "react-icons/fa"
    tag = "FaHeadSideMask"


class FaHeadSideVirus(rx.Component):
    library = "react-icons/fa"
    tag = "FaHeadSideVirus"


class FaHeading(rx.Component):
    library = "react-icons/fa"
    tag = "FaHeading"


class FaHeadphonesAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaHeadphonesAlt"


class FaHeadphones(rx.Component):
    library = "react-icons/fa"
    tag = "FaHeadphones"


class FaHeadset(rx.Component):
    library = "react-icons/fa"
    tag = "FaHeadset"


class FaHeartBroken(rx.Component):
    library = "react-icons/fa"
    tag = "FaHeartBroken"


class FaHeart(rx.Component):
    library = "react-icons/fa"
    tag = "FaHeart"


class FaHeartbeat(rx.Component):
    library = "react-icons/fa"
    tag = "FaHeartbeat"


class FaHelicopter(rx.Component):
    library = "react-icons/fa"
    tag = "FaHelicopter"


class FaHighlighter(rx.Component):
    library = "react-icons/fa"
    tag = "FaHighlighter"


class FaHiking(rx.Component):
    library = "react-icons/fa"
    tag = "FaHiking"


class FaHippo(rx.Component):
    library = "react-icons/fa"
    tag = "FaHippo"


class FaHistory(rx.Component):
    library = "react-icons/fa"
    tag = "FaHistory"


class FaHockeyPuck(rx.Component):
    library = "react-icons/fa"
    tag = "FaHockeyPuck"


class FaHollyBerry(rx.Component):
    library = "react-icons/fa"
    tag = "FaHollyBerry"


class FaHome(rx.Component):
    library = "react-icons/fa"
    tag = "FaHome"


class FaHorseHead(rx.Component):
    library = "react-icons/fa"
    tag = "FaHorseHead"


class FaHorse(rx.Component):
    library = "react-icons/fa"
    tag = "FaHorse"


class FaHospitalAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaHospitalAlt"


class FaHospitalSymbol(rx.Component):
    library = "react-icons/fa"
    tag = "FaHospitalSymbol"


class FaHospitalUser(rx.Component):
    library = "react-icons/fa"
    tag = "FaHospitalUser"


class FaHospital(rx.Component):
    library = "react-icons/fa"
    tag = "FaHospital"


class FaHotTub(rx.Component):
    library = "react-icons/fa"
    tag = "FaHotTub"


class FaHotdog(rx.Component):
    library = "react-icons/fa"
    tag = "FaHotdog"


class FaHotel(rx.Component):
    library = "react-icons/fa"
    tag = "FaHotel"


class FaHourglassEnd(rx.Component):
    library = "react-icons/fa"
    tag = "FaHourglassEnd"


class FaHourglassHalf(rx.Component):
    library = "react-icons/fa"
    tag = "FaHourglassHalf"


class FaHourglassStart(rx.Component):
    library = "react-icons/fa"
    tag = "FaHourglassStart"


class FaHourglass(rx.Component):
    library = "react-icons/fa"
    tag = "FaHourglass"


class FaHouseDamage(rx.Component):
    library = "react-icons/fa"
    tag = "FaHouseDamage"


class FaHouseUser(rx.Component):
    library = "react-icons/fa"
    tag = "FaHouseUser"


class FaHryvnia(rx.Component):
    library = "react-icons/fa"
    tag = "FaHryvnia"


class FaICursor(rx.Component):
    library = "react-icons/fa"
    tag = "FaICursor"


class FaIceCream(rx.Component):
    library = "react-icons/fa"
    tag = "FaIceCream"


class FaIcicles(rx.Component):
    library = "react-icons/fa"
    tag = "FaIcicles"


class FaIcons(rx.Component):
    library = "react-icons/fa"
    tag = "FaIcons"


class FaIdBadge(rx.Component):
    library = "react-icons/fa"
    tag = "FaIdBadge"


class FaIdCardAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaIdCardAlt"


class FaIdCard(rx.Component):
    library = "react-icons/fa"
    tag = "FaIdCard"


class FaIgloo(rx.Component):
    library = "react-icons/fa"
    tag = "FaIgloo"


class FaImage(rx.Component):
    library = "react-icons/fa"
    tag = "FaImage"


class FaImages(rx.Component):
    library = "react-icons/fa"
    tag = "FaImages"


class FaInbox(rx.Component):
    library = "react-icons/fa"
    tag = "FaInbox"


class FaIndent(rx.Component):
    library = "react-icons/fa"
    tag = "FaIndent"


class FaIndustry(rx.Component):
    library = "react-icons/fa"
    tag = "FaIndustry"


class FaInfinity(rx.Component):
    library = "react-icons/fa"
    tag = "FaInfinity"


class FaInfoCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaInfoCircle"


class FaInfo(rx.Component):
    library = "react-icons/fa"
    tag = "FaInfo"


class FaItalic(rx.Component):
    library = "react-icons/fa"
    tag = "FaItalic"


class FaJedi(rx.Component):
    library = "react-icons/fa"
    tag = "FaJedi"


class FaJoint(rx.Component):
    library = "react-icons/fa"
    tag = "FaJoint"


class FaJournalWhills(rx.Component):
    library = "react-icons/fa"
    tag = "FaJournalWhills"


class FaKaaba(rx.Component):
    library = "react-icons/fa"
    tag = "FaKaaba"


class FaKey(rx.Component):
    library = "react-icons/fa"
    tag = "FaKey"


class FaKeyboard(rx.Component):
    library = "react-icons/fa"
    tag = "FaKeyboard"


class FaKhanda(rx.Component):
    library = "react-icons/fa"
    tag = "FaKhanda"


class FaKissBeam(rx.Component):
    library = "react-icons/fa"
    tag = "FaKissBeam"


class FaKissWinkHeart(rx.Component):
    library = "react-icons/fa"
    tag = "FaKissWinkHeart"


class FaKiss(rx.Component):
    library = "react-icons/fa"
    tag = "FaKiss"


class FaKiwiBird(rx.Component):
    library = "react-icons/fa"
    tag = "FaKiwiBird"


class FaLandmark(rx.Component):
    library = "react-icons/fa"
    tag = "FaLandmark"


class FaLanguage(rx.Component):
    library = "react-icons/fa"
    tag = "FaLanguage"


class FaLaptopCode(rx.Component):
    library = "react-icons/fa"
    tag = "FaLaptopCode"


class FaLaptopHouse(rx.Component):
    library = "react-icons/fa"
    tag = "FaLaptopHouse"


class FaLaptopMedical(rx.Component):
    library = "react-icons/fa"
    tag = "FaLaptopMedical"


class FaLaptop(rx.Component):
    library = "react-icons/fa"
    tag = "FaLaptop"


class FaLaughBeam(rx.Component):
    library = "react-icons/fa"
    tag = "FaLaughBeam"


class FaLaughSquint(rx.Component):
    library = "react-icons/fa"
    tag = "FaLaughSquint"


class FaLaughWink(rx.Component):
    library = "react-icons/fa"
    tag = "FaLaughWink"


class FaLaugh(rx.Component):
    library = "react-icons/fa"
    tag = "FaLaugh"


class FaLayerGroup(rx.Component):
    library = "react-icons/fa"
    tag = "FaLayerGroup"


class FaLeaf(rx.Component):
    library = "react-icons/fa"
    tag = "FaLeaf"


class FaLemon(rx.Component):
    library = "react-icons/fa"
    tag = "FaLemon"


class FaLessThanEqual(rx.Component):
    library = "react-icons/fa"
    tag = "FaLessThanEqual"


class FaLessThan(rx.Component):
    library = "react-icons/fa"
    tag = "FaLessThan"


class FaLevelDownAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaLevelDownAlt"


class FaLevelUpAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaLevelUpAlt"


class FaLifeRing(rx.Component):
    library = "react-icons/fa"
    tag = "FaLifeRing"


class FaLightbulb(rx.Component):
    library = "react-icons/fa"
    tag = "FaLightbulb"


class FaLink(rx.Component):
    library = "react-icons/fa"
    tag = "FaLink"


class FaLiraSign(rx.Component):
    library = "react-icons/fa"
    tag = "FaLiraSign"


class FaListAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaListAlt"


class FaListOl(rx.Component):
    library = "react-icons/fa"
    tag = "FaListOl"


class FaListUl(rx.Component):
    library = "react-icons/fa"
    tag = "FaListUl"


class FaList(rx.Component):
    library = "react-icons/fa"
    tag = "FaList"


class FaLocationArrow(rx.Component):
    library = "react-icons/fa"
    tag = "FaLocationArrow"


class FaLockOpen(rx.Component):
    library = "react-icons/fa"
    tag = "FaLockOpen"


class FaLock(rx.Component):
    library = "react-icons/fa"
    tag = "FaLock"


class FaLongArrowAltDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaLongArrowAltDown"


class FaLongArrowAltLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaLongArrowAltLeft"


class FaLongArrowAltRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaLongArrowAltRight"


class FaLongArrowAltUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaLongArrowAltUp"


class FaLowVision(rx.Component):
    library = "react-icons/fa"
    tag = "FaLowVision"


class FaLuggageCart(rx.Component):
    library = "react-icons/fa"
    tag = "FaLuggageCart"


class FaLungsVirus(rx.Component):
    library = "react-icons/fa"
    tag = "FaLungsVirus"


class FaLungs(rx.Component):
    library = "react-icons/fa"
    tag = "FaLungs"


class FaMagic(rx.Component):
    library = "react-icons/fa"
    tag = "FaMagic"


class FaMagnet(rx.Component):
    library = "react-icons/fa"
    tag = "FaMagnet"


class FaMailBulk(rx.Component):
    library = "react-icons/fa"
    tag = "FaMailBulk"


class FaMale(rx.Component):
    library = "react-icons/fa"
    tag = "FaMale"


class FaMapMarkedAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaMapMarkedAlt"


class FaMapMarked(rx.Component):
    library = "react-icons/fa"
    tag = "FaMapMarked"


class FaMapMarkerAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaMapMarkerAlt"


class FaMapMarker(rx.Component):
    library = "react-icons/fa"
    tag = "FaMapMarker"


class FaMapPin(rx.Component):
    library = "react-icons/fa"
    tag = "FaMapPin"


class FaMapSigns(rx.Component):
    library = "react-icons/fa"
    tag = "FaMapSigns"


class FaMap(rx.Component):
    library = "react-icons/fa"
    tag = "FaMap"


class FaMarker(rx.Component):
    library = "react-icons/fa"
    tag = "FaMarker"


class FaMarsDouble(rx.Component):
    library = "react-icons/fa"
    tag = "FaMarsDouble"


class FaMarsStrokeH(rx.Component):
    library = "react-icons/fa"
    tag = "FaMarsStrokeH"


class FaMarsStrokeV(rx.Component):
    library = "react-icons/fa"
    tag = "FaMarsStrokeV"


class FaMarsStroke(rx.Component):
    library = "react-icons/fa"
    tag = "FaMarsStroke"


class FaMars(rx.Component):
    library = "react-icons/fa"
    tag = "FaMars"


class FaMask(rx.Component):
    library = "react-icons/fa"
    tag = "FaMask"


class FaMedal(rx.Component):
    library = "react-icons/fa"
    tag = "FaMedal"


class FaMedkit(rx.Component):
    library = "react-icons/fa"
    tag = "FaMedkit"


class FaMehBlank(rx.Component):
    library = "react-icons/fa"
    tag = "FaMehBlank"


class FaMehRollingEyes(rx.Component):
    library = "react-icons/fa"
    tag = "FaMehRollingEyes"


class FaMeh(rx.Component):
    library = "react-icons/fa"
    tag = "FaMeh"


class FaMemory(rx.Component):
    library = "react-icons/fa"
    tag = "FaMemory"


class FaMenorah(rx.Component):
    library = "react-icons/fa"
    tag = "FaMenorah"


class FaMercury(rx.Component):
    library = "react-icons/fa"
    tag = "FaMercury"


class FaMeteor(rx.Component):
    library = "react-icons/fa"
    tag = "FaMeteor"


class FaMicrochip(rx.Component):
    library = "react-icons/fa"
    tag = "FaMicrochip"


class FaMicrophoneAltSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaMicrophoneAltSlash"


class FaMicrophoneAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaMicrophoneAlt"


class FaMicrophoneSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaMicrophoneSlash"


class FaMicrophone(rx.Component):
    library = "react-icons/fa"
    tag = "FaMicrophone"


class FaMicroscope(rx.Component):
    library = "react-icons/fa"
    tag = "FaMicroscope"


class FaMinusCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaMinusCircle"


class FaMinusSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaMinusSquare"


class FaMinus(rx.Component):
    library = "react-icons/fa"
    tag = "FaMinus"


class FaMitten(rx.Component):
    library = "react-icons/fa"
    tag = "FaMitten"


class FaMobileAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaMobileAlt"


class FaMobile(rx.Component):
    library = "react-icons/fa"
    tag = "FaMobile"


class FaMoneyBillAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaMoneyBillAlt"


class FaMoneyBillWaveAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaMoneyBillWaveAlt"


class FaMoneyBillWave(rx.Component):
    library = "react-icons/fa"
    tag = "FaMoneyBillWave"


class FaMoneyBill(rx.Component):
    library = "react-icons/fa"
    tag = "FaMoneyBill"


class FaMoneyCheckAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaMoneyCheckAlt"


class FaMoneyCheck(rx.Component):
    library = "react-icons/fa"
    tag = "FaMoneyCheck"


class FaMonument(rx.Component):
    library = "react-icons/fa"
    tag = "FaMonument"


class FaMoon(rx.Component):
    library = "react-icons/fa"
    tag = "FaMoon"


class FaMortarPestle(rx.Component):
    library = "react-icons/fa"
    tag = "FaMortarPestle"


class FaMosque(rx.Component):
    library = "react-icons/fa"
    tag = "FaMosque"


class FaMotorcycle(rx.Component):
    library = "react-icons/fa"
    tag = "FaMotorcycle"


class FaMountain(rx.Component):
    library = "react-icons/fa"
    tag = "FaMountain"


class FaMousePointer(rx.Component):
    library = "react-icons/fa"
    tag = "FaMousePointer"


class FaMouse(rx.Component):
    library = "react-icons/fa"
    tag = "FaMouse"


class FaMugHot(rx.Component):
    library = "react-icons/fa"
    tag = "FaMugHot"


class FaMusic(rx.Component):
    library = "react-icons/fa"
    tag = "FaMusic"


class FaNetworkWired(rx.Component):
    library = "react-icons/fa"
    tag = "FaNetworkWired"


class FaNeuter(rx.Component):
    library = "react-icons/fa"
    tag = "FaNeuter"


class FaNewspaper(rx.Component):
    library = "react-icons/fa"
    tag = "FaNewspaper"


class FaNotEqual(rx.Component):
    library = "react-icons/fa"
    tag = "FaNotEqual"


class FaNotesMedical(rx.Component):
    library = "react-icons/fa"
    tag = "FaNotesMedical"


class FaObjectGroup(rx.Component):
    library = "react-icons/fa"
    tag = "FaObjectGroup"


class FaObjectUngroup(rx.Component):
    library = "react-icons/fa"
    tag = "FaObjectUngroup"


class FaOilCan(rx.Component):
    library = "react-icons/fa"
    tag = "FaOilCan"


class FaOm(rx.Component):
    library = "react-icons/fa"
    tag = "FaOm"


class FaOtter(rx.Component):
    library = "react-icons/fa"
    tag = "FaOtter"


class FaOutdent(rx.Component):
    library = "react-icons/fa"
    tag = "FaOutdent"


class FaPager(rx.Component):
    library = "react-icons/fa"
    tag = "FaPager"


class FaPaintBrush(rx.Component):
    library = "react-icons/fa"
    tag = "FaPaintBrush"


class FaPaintRoller(rx.Component):
    library = "react-icons/fa"
    tag = "FaPaintRoller"


class FaPalette(rx.Component):
    library = "react-icons/fa"
    tag = "FaPalette"


class FaPallet(rx.Component):
    library = "react-icons/fa"
    tag = "FaPallet"


class FaPaperPlane(rx.Component):
    library = "react-icons/fa"
    tag = "FaPaperPlane"


class FaPaperclip(rx.Component):
    library = "react-icons/fa"
    tag = "FaPaperclip"


class FaParachuteBox(rx.Component):
    library = "react-icons/fa"
    tag = "FaParachuteBox"


class FaParagraph(rx.Component):
    library = "react-icons/fa"
    tag = "FaParagraph"


class FaParking(rx.Component):
    library = "react-icons/fa"
    tag = "FaParking"


class FaPassport(rx.Component):
    library = "react-icons/fa"
    tag = "FaPassport"


class FaPastafarianism(rx.Component):
    library = "react-icons/fa"
    tag = "FaPastafarianism"


class FaPaste(rx.Component):
    library = "react-icons/fa"
    tag = "FaPaste"


class FaPauseCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaPauseCircle"


class FaPause(rx.Component):
    library = "react-icons/fa"
    tag = "FaPause"


class FaPaw(rx.Component):
    library = "react-icons/fa"
    tag = "FaPaw"


class FaPeace(rx.Component):
    library = "react-icons/fa"
    tag = "FaPeace"


class FaPenAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaPenAlt"


class FaPenFancy(rx.Component):
    library = "react-icons/fa"
    tag = "FaPenFancy"


class FaPenNib(rx.Component):
    library = "react-icons/fa"
    tag = "FaPenNib"


class FaPenSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaPenSquare"


class FaPen(rx.Component):
    library = "react-icons/fa"
    tag = "FaPen"


class FaPencilAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaPencilAlt"


class FaPencilRuler(rx.Component):
    library = "react-icons/fa"
    tag = "FaPencilRuler"


class FaPeopleArrows(rx.Component):
    library = "react-icons/fa"
    tag = "FaPeopleArrows"


class FaPeopleCarry(rx.Component):
    library = "react-icons/fa"
    tag = "FaPeopleCarry"


class FaPepperHot(rx.Component):
    library = "react-icons/fa"
    tag = "FaPepperHot"


class FaPercent(rx.Component):
    library = "react-icons/fa"
    tag = "FaPercent"


class FaPercentage(rx.Component):
    library = "react-icons/fa"
    tag = "FaPercentage"


class FaPersonBooth(rx.Component):
    library = "react-icons/fa"
    tag = "FaPersonBooth"


class FaPhoneAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaPhoneAlt"


class FaPhoneSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaPhoneSlash"


class FaPhoneSquareAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaPhoneSquareAlt"


class FaPhoneSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaPhoneSquare"


class FaPhoneVolume(rx.Component):
    library = "react-icons/fa"
    tag = "FaPhoneVolume"


class FaPhone(rx.Component):
    library = "react-icons/fa"
    tag = "FaPhone"


class FaPhotoVideo(rx.Component):
    library = "react-icons/fa"
    tag = "FaPhotoVideo"


class FaPiggyBank(rx.Component):
    library = "react-icons/fa"
    tag = "FaPiggyBank"


class FaPills(rx.Component):
    library = "react-icons/fa"
    tag = "FaPills"


class FaPizzaSlice(rx.Component):
    library = "react-icons/fa"
    tag = "FaPizzaSlice"


class FaPlaceOfWorship(rx.Component):
    library = "react-icons/fa"
    tag = "FaPlaceOfWorship"


class FaPlaneArrival(rx.Component):
    library = "react-icons/fa"
    tag = "FaPlaneArrival"


class FaPlaneDeparture(rx.Component):
    library = "react-icons/fa"
    tag = "FaPlaneDeparture"


class FaPlaneSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaPlaneSlash"


class FaPlane(rx.Component):
    library = "react-icons/fa"
    tag = "FaPlane"


class FaPlayCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaPlayCircle"


class FaPlay(rx.Component):
    library = "react-icons/fa"
    tag = "FaPlay"


class FaPlug(rx.Component):
    library = "react-icons/fa"
    tag = "FaPlug"


class FaPlusCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaPlusCircle"


class FaPlusSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaPlusSquare"


class FaPlus(rx.Component):
    library = "react-icons/fa"
    tag = "FaPlus"


class FaPodcast(rx.Component):
    library = "react-icons/fa"
    tag = "FaPodcast"


class FaPollH(rx.Component):
    library = "react-icons/fa"
    tag = "FaPollH"


class FaPoll(rx.Component):
    library = "react-icons/fa"
    tag = "FaPoll"


class FaPooStorm(rx.Component):
    library = "react-icons/fa"
    tag = "FaPooStorm"


class FaPoo(rx.Component):
    library = "react-icons/fa"
    tag = "FaPoo"


class FaPoop(rx.Component):
    library = "react-icons/fa"
    tag = "FaPoop"


class FaPortrait(rx.Component):
    library = "react-icons/fa"
    tag = "FaPortrait"


class FaPoundSign(rx.Component):
    library = "react-icons/fa"
    tag = "FaPoundSign"


class FaPowerOff(rx.Component):
    library = "react-icons/fa"
    tag = "FaPowerOff"


class FaPray(rx.Component):
    library = "react-icons/fa"
    tag = "FaPray"


class FaPrayingHands(rx.Component):
    library = "react-icons/fa"
    tag = "FaPrayingHands"


class FaPrescriptionBottleAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaPrescriptionBottleAlt"


class FaPrescriptionBottle(rx.Component):
    library = "react-icons/fa"
    tag = "FaPrescriptionBottle"


class FaPrescription(rx.Component):
    library = "react-icons/fa"
    tag = "FaPrescription"


class FaPrint(rx.Component):
    library = "react-icons/fa"
    tag = "FaPrint"


class FaProcedures(rx.Component):
    library = "react-icons/fa"
    tag = "FaProcedures"


class FaProjectDiagram(rx.Component):
    library = "react-icons/fa"
    tag = "FaProjectDiagram"


class FaPumpMedical(rx.Component):
    library = "react-icons/fa"
    tag = "FaPumpMedical"


class FaPumpSoap(rx.Component):
    library = "react-icons/fa"
    tag = "FaPumpSoap"


class FaPuzzlePiece(rx.Component):
    library = "react-icons/fa"
    tag = "FaPuzzlePiece"


class FaQrcode(rx.Component):
    library = "react-icons/fa"
    tag = "FaQrcode"


class FaQuestionCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaQuestionCircle"


class FaQuestion(rx.Component):
    library = "react-icons/fa"
    tag = "FaQuestion"


class FaQuidditch(rx.Component):
    library = "react-icons/fa"
    tag = "FaQuidditch"


class FaQuoteLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaQuoteLeft"


class FaQuoteRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaQuoteRight"


class FaQuran(rx.Component):
    library = "react-icons/fa"
    tag = "FaQuran"


class FaRadiationAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaRadiationAlt"


class FaRadiation(rx.Component):
    library = "react-icons/fa"
    tag = "FaRadiation"


class FaRainbow(rx.Component):
    library = "react-icons/fa"
    tag = "FaRainbow"


class FaRandom(rx.Component):
    library = "react-icons/fa"
    tag = "FaRandom"


class FaReceipt(rx.Component):
    library = "react-icons/fa"
    tag = "FaReceipt"


class FaRecordVinyl(rx.Component):
    library = "react-icons/fa"
    tag = "FaRecordVinyl"


class FaRecycle(rx.Component):
    library = "react-icons/fa"
    tag = "FaRecycle"


class FaRedoAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaRedoAlt"


class FaRedo(rx.Component):
    library = "react-icons/fa"
    tag = "FaRedo"


class FaRegistered(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegistered"


class FaRemoveFormat(rx.Component):
    library = "react-icons/fa"
    tag = "FaRemoveFormat"


class FaReplyAll(rx.Component):
    library = "react-icons/fa"
    tag = "FaReplyAll"


class FaReply(rx.Component):
    library = "react-icons/fa"
    tag = "FaReply"


class FaRepublican(rx.Component):
    library = "react-icons/fa"
    tag = "FaRepublican"


class FaRestroom(rx.Component):
    library = "react-icons/fa"
    tag = "FaRestroom"


class FaRetweet(rx.Component):
    library = "react-icons/fa"
    tag = "FaRetweet"


class FaRibbon(rx.Component):
    library = "react-icons/fa"
    tag = "FaRibbon"


class FaRing(rx.Component):
    library = "react-icons/fa"
    tag = "FaRing"


class FaRoad(rx.Component):
    library = "react-icons/fa"
    tag = "FaRoad"


class FaRobot(rx.Component):
    library = "react-icons/fa"
    tag = "FaRobot"


class FaRocket(rx.Component):
    library = "react-icons/fa"
    tag = "FaRocket"


class FaRoute(rx.Component):
    library = "react-icons/fa"
    tag = "FaRoute"


class FaRssSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaRssSquare"


class FaRss(rx.Component):
    library = "react-icons/fa"
    tag = "FaRss"


class FaRubleSign(rx.Component):
    library = "react-icons/fa"
    tag = "FaRubleSign"


class FaRulerCombined(rx.Component):
    library = "react-icons/fa"
    tag = "FaRulerCombined"


class FaRulerHorizontal(rx.Component):
    library = "react-icons/fa"
    tag = "FaRulerHorizontal"


class FaRulerVertical(rx.Component):
    library = "react-icons/fa"
    tag = "FaRulerVertical"


class FaRuler(rx.Component):
    library = "react-icons/fa"
    tag = "FaRuler"


class FaRunning(rx.Component):
    library = "react-icons/fa"
    tag = "FaRunning"


class FaRupeeSign(rx.Component):
    library = "react-icons/fa"
    tag = "FaRupeeSign"


class FaSadCry(rx.Component):
    library = "react-icons/fa"
    tag = "FaSadCry"


class FaSadTear(rx.Component):
    library = "react-icons/fa"
    tag = "FaSadTear"


class FaSatelliteDish(rx.Component):
    library = "react-icons/fa"
    tag = "FaSatelliteDish"


class FaSatellite(rx.Component):
    library = "react-icons/fa"
    tag = "FaSatellite"


class FaSave(rx.Component):
    library = "react-icons/fa"
    tag = "FaSave"


class FaSchool(rx.Component):
    library = "react-icons/fa"
    tag = "FaSchool"


class FaScrewdriver(rx.Component):
    library = "react-icons/fa"
    tag = "FaScrewdriver"


class FaScroll(rx.Component):
    library = "react-icons/fa"
    tag = "FaScroll"


class FaSdCard(rx.Component):
    library = "react-icons/fa"
    tag = "FaSdCard"


class FaSearchDollar(rx.Component):
    library = "react-icons/fa"
    tag = "FaSearchDollar"


class FaSearchLocation(rx.Component):
    library = "react-icons/fa"
    tag = "FaSearchLocation"


class FaSearchMinus(rx.Component):
    library = "react-icons/fa"
    tag = "FaSearchMinus"


class FaSearchPlus(rx.Component):
    library = "react-icons/fa"
    tag = "FaSearchPlus"


class FaSearch(rx.Component):
    library = "react-icons/fa"
    tag = "FaSearch"


class FaSeedling(rx.Component):
    library = "react-icons/fa"
    tag = "FaSeedling"


class FaServer(rx.Component):
    library = "react-icons/fa"
    tag = "FaServer"


class FaShapes(rx.Component):
    library = "react-icons/fa"
    tag = "FaShapes"


class FaShareAltSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaShareAltSquare"


class FaShareAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaShareAlt"


class FaShareSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaShareSquare"


class FaShare(rx.Component):
    library = "react-icons/fa"
    tag = "FaShare"


class FaShekelSign(rx.Component):
    library = "react-icons/fa"
    tag = "FaShekelSign"


class FaShieldAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaShieldAlt"


class FaShieldVirus(rx.Component):
    library = "react-icons/fa"
    tag = "FaShieldVirus"


class FaShip(rx.Component):
    library = "react-icons/fa"
    tag = "FaShip"


class FaShippingFast(rx.Component):
    library = "react-icons/fa"
    tag = "FaShippingFast"


class FaShoePrints(rx.Component):
    library = "react-icons/fa"
    tag = "FaShoePrints"


class FaShoppingBag(rx.Component):
    library = "react-icons/fa"
    tag = "FaShoppingBag"


class FaShoppingBasket(rx.Component):
    library = "react-icons/fa"
    tag = "FaShoppingBasket"


class FaShoppingCart(rx.Component):
    library = "react-icons/fa"
    tag = "FaShoppingCart"


class FaShower(rx.Component):
    library = "react-icons/fa"
    tag = "FaShower"


class FaShuttleVan(rx.Component):
    library = "react-icons/fa"
    tag = "FaShuttleVan"


class FaSignInAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaSignInAlt"


class FaSignLanguage(rx.Component):
    library = "react-icons/fa"
    tag = "FaSignLanguage"


class FaSignOutAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaSignOutAlt"


class FaSign(rx.Component):
    library = "react-icons/fa"
    tag = "FaSign"


class FaSignal(rx.Component):
    library = "react-icons/fa"
    tag = "FaSignal"


class FaSignature(rx.Component):
    library = "react-icons/fa"
    tag = "FaSignature"


class FaSimCard(rx.Component):
    library = "react-icons/fa"
    tag = "FaSimCard"


class FaSink(rx.Component):
    library = "react-icons/fa"
    tag = "FaSink"


class FaSitemap(rx.Component):
    library = "react-icons/fa"
    tag = "FaSitemap"


class FaSkating(rx.Component):
    library = "react-icons/fa"
    tag = "FaSkating"


class FaSkiingNordic(rx.Component):
    library = "react-icons/fa"
    tag = "FaSkiingNordic"


class FaSkiing(rx.Component):
    library = "react-icons/fa"
    tag = "FaSkiing"


class FaSkullCrossbones(rx.Component):
    library = "react-icons/fa"
    tag = "FaSkullCrossbones"


class FaSkull(rx.Component):
    library = "react-icons/fa"
    tag = "FaSkull"


class FaSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaSlash"


class FaSleigh(rx.Component):
    library = "react-icons/fa"
    tag = "FaSleigh"


class FaSlidersH(rx.Component):
    library = "react-icons/fa"
    tag = "FaSlidersH"


class FaSmileBeam(rx.Component):
    library = "react-icons/fa"
    tag = "FaSmileBeam"


class FaSmileWink(rx.Component):
    library = "react-icons/fa"
    tag = "FaSmileWink"


class FaSmile(rx.Component):
    library = "react-icons/fa"
    tag = "FaSmile"


class FaSmog(rx.Component):
    library = "react-icons/fa"
    tag = "FaSmog"


class FaSmokingBan(rx.Component):
    library = "react-icons/fa"
    tag = "FaSmokingBan"


class FaSmoking(rx.Component):
    library = "react-icons/fa"
    tag = "FaSmoking"


class FaSms(rx.Component):
    library = "react-icons/fa"
    tag = "FaSms"


class FaSnowboarding(rx.Component):
    library = "react-icons/fa"
    tag = "FaSnowboarding"


class FaSnowflake(rx.Component):
    library = "react-icons/fa"
    tag = "FaSnowflake"


class FaSnowman(rx.Component):
    library = "react-icons/fa"
    tag = "FaSnowman"


class FaSnowplow(rx.Component):
    library = "react-icons/fa"
    tag = "FaSnowplow"


class FaSoap(rx.Component):
    library = "react-icons/fa"
    tag = "FaSoap"


class FaSocks(rx.Component):
    library = "react-icons/fa"
    tag = "FaSocks"


class FaSolarPanel(rx.Component):
    library = "react-icons/fa"
    tag = "FaSolarPanel"


class FaSortAlphaDownAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortAlphaDownAlt"


class FaSortAlphaDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortAlphaDown"


class FaSortAlphaUpAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortAlphaUpAlt"


class FaSortAlphaUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortAlphaUp"


class FaSortAmountDownAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortAmountDownAlt"


class FaSortAmountDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortAmountDown"


class FaSortAmountUpAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortAmountUpAlt"


class FaSortAmountUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortAmountUp"


class FaSortDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortDown"


class FaSortNumericDownAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortNumericDownAlt"


class FaSortNumericDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortNumericDown"


class FaSortNumericUpAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortNumericUpAlt"


class FaSortNumericUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortNumericUp"


class FaSortUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaSortUp"


class FaSort(rx.Component):
    library = "react-icons/fa"
    tag = "FaSort"


class FaSpa(rx.Component):
    library = "react-icons/fa"
    tag = "FaSpa"


class FaSpaceShuttle(rx.Component):
    library = "react-icons/fa"
    tag = "FaSpaceShuttle"


class FaSpellCheck(rx.Component):
    library = "react-icons/fa"
    tag = "FaSpellCheck"


class FaSpider(rx.Component):
    library = "react-icons/fa"
    tag = "FaSpider"


class FaSpinner(rx.Component):
    library = "react-icons/fa"
    tag = "FaSpinner"


class FaSplotch(rx.Component):
    library = "react-icons/fa"
    tag = "FaSplotch"


class FaSprayCan(rx.Component):
    library = "react-icons/fa"
    tag = "FaSprayCan"


class FaSquareFull(rx.Component):
    library = "react-icons/fa"
    tag = "FaSquareFull"


class FaSquareRootAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaSquareRootAlt"


class FaSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaSquare"


class FaStamp(rx.Component):
    library = "react-icons/fa"
    tag = "FaStamp"


class FaStarAndCrescent(rx.Component):
    library = "react-icons/fa"
    tag = "FaStarAndCrescent"


class FaStarHalfAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaStarHalfAlt"


class FaStarHalf(rx.Component):
    library = "react-icons/fa"
    tag = "FaStarHalf"


class FaStarOfDavid(rx.Component):
    library = "react-icons/fa"
    tag = "FaStarOfDavid"


class FaStarOfLife(rx.Component):
    library = "react-icons/fa"
    tag = "FaStarOfLife"


class FaStar(rx.Component):
    library = "react-icons/fa"
    tag = "FaStar"


class FaStepBackward(rx.Component):
    library = "react-icons/fa"
    tag = "FaStepBackward"


class FaStepForward(rx.Component):
    library = "react-icons/fa"
    tag = "FaStepForward"


class FaStethoscope(rx.Component):
    library = "react-icons/fa"
    tag = "FaStethoscope"


class FaStickyNote(rx.Component):
    library = "react-icons/fa"
    tag = "FaStickyNote"


class FaStopCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaStopCircle"


class FaStop(rx.Component):
    library = "react-icons/fa"
    tag = "FaStop"


class FaStopwatch20(rx.Component):
    library = "react-icons/fa"
    tag = "FaStopwatch20"


class FaStopwatch(rx.Component):
    library = "react-icons/fa"
    tag = "FaStopwatch"


class FaStoreAltSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaStoreAltSlash"


class FaStoreAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaStoreAlt"


class FaStoreSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaStoreSlash"


class FaStore(rx.Component):
    library = "react-icons/fa"
    tag = "FaStore"


class FaStream(rx.Component):
    library = "react-icons/fa"
    tag = "FaStream"


class FaStreetView(rx.Component):
    library = "react-icons/fa"
    tag = "FaStreetView"


class FaStrikethrough(rx.Component):
    library = "react-icons/fa"
    tag = "FaStrikethrough"


class FaStroopwafel(rx.Component):
    library = "react-icons/fa"
    tag = "FaStroopwafel"


class FaSubscript(rx.Component):
    library = "react-icons/fa"
    tag = "FaSubscript"


class FaSubway(rx.Component):
    library = "react-icons/fa"
    tag = "FaSubway"


class FaSuitcaseRolling(rx.Component):
    library = "react-icons/fa"
    tag = "FaSuitcaseRolling"


class FaSuitcase(rx.Component):
    library = "react-icons/fa"
    tag = "FaSuitcase"


class FaSun(rx.Component):
    library = "react-icons/fa"
    tag = "FaSun"


class FaSuperscript(rx.Component):
    library = "react-icons/fa"
    tag = "FaSuperscript"


class FaSurprise(rx.Component):
    library = "react-icons/fa"
    tag = "FaSurprise"


class FaSwatchbook(rx.Component):
    library = "react-icons/fa"
    tag = "FaSwatchbook"


class FaSwimmer(rx.Component):
    library = "react-icons/fa"
    tag = "FaSwimmer"


class FaSwimmingPool(rx.Component):
    library = "react-icons/fa"
    tag = "FaSwimmingPool"


class FaSynagogue(rx.Component):
    library = "react-icons/fa"
    tag = "FaSynagogue"


class FaSyncAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaSyncAlt"


class FaSync(rx.Component):
    library = "react-icons/fa"
    tag = "FaSync"


class FaSyringe(rx.Component):
    library = "react-icons/fa"
    tag = "FaSyringe"


class FaTableTennis(rx.Component):
    library = "react-icons/fa"
    tag = "FaTableTennis"


class FaTable(rx.Component):
    library = "react-icons/fa"
    tag = "FaTable"


class FaTabletAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaTabletAlt"


class FaTablet(rx.Component):
    library = "react-icons/fa"
    tag = "FaTablet"


class FaTablets(rx.Component):
    library = "react-icons/fa"
    tag = "FaTablets"


class FaTachometerAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaTachometerAlt"


class FaTag(rx.Component):
    library = "react-icons/fa"
    tag = "FaTag"


class FaTags(rx.Component):
    library = "react-icons/fa"
    tag = "FaTags"


class FaTape(rx.Component):
    library = "react-icons/fa"
    tag = "FaTape"


class FaTasks(rx.Component):
    library = "react-icons/fa"
    tag = "FaTasks"


class FaTaxi(rx.Component):
    library = "react-icons/fa"
    tag = "FaTaxi"


class FaTeethOpen(rx.Component):
    library = "react-icons/fa"
    tag = "FaTeethOpen"


class FaTeeth(rx.Component):
    library = "react-icons/fa"
    tag = "FaTeeth"


class FaTemperatureHigh(rx.Component):
    library = "react-icons/fa"
    tag = "FaTemperatureHigh"


class FaTemperatureLow(rx.Component):
    library = "react-icons/fa"
    tag = "FaTemperatureLow"


class FaTenge(rx.Component):
    library = "react-icons/fa"
    tag = "FaTenge"


class FaTerminal(rx.Component):
    library = "react-icons/fa"
    tag = "FaTerminal"


class FaTextHeight(rx.Component):
    library = "react-icons/fa"
    tag = "FaTextHeight"


class FaTextWidth(rx.Component):
    library = "react-icons/fa"
    tag = "FaTextWidth"


class FaThLarge(rx.Component):
    library = "react-icons/fa"
    tag = "FaThLarge"


class FaThList(rx.Component):
    library = "react-icons/fa"
    tag = "FaThList"


class FaTh(rx.Component):
    library = "react-icons/fa"
    tag = "FaTh"


class FaTheaterMasks(rx.Component):
    library = "react-icons/fa"
    tag = "FaTheaterMasks"


class FaThermometerEmpty(rx.Component):
    library = "react-icons/fa"
    tag = "FaThermometerEmpty"


class FaThermometerFull(rx.Component):
    library = "react-icons/fa"
    tag = "FaThermometerFull"


class FaThermometerHalf(rx.Component):
    library = "react-icons/fa"
    tag = "FaThermometerHalf"


class FaThermometerQuarter(rx.Component):
    library = "react-icons/fa"
    tag = "FaThermometerQuarter"


class FaThermometerThreeQuarters(rx.Component):
    library = "react-icons/fa"
    tag = "FaThermometerThreeQuarters"


class FaThermometer(rx.Component):
    library = "react-icons/fa"
    tag = "FaThermometer"


class FaThumbsDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaThumbsDown"


class FaThumbsUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaThumbsUp"


class FaThumbtack(rx.Component):
    library = "react-icons/fa"
    tag = "FaThumbtack"


class FaTicketAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaTicketAlt"


class FaTimesCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaTimesCircle"


class FaTimes(rx.Component):
    library = "react-icons/fa"
    tag = "FaTimes"


class FaTintSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaTintSlash"


class FaTint(rx.Component):
    library = "react-icons/fa"
    tag = "FaTint"


class FaTired(rx.Component):
    library = "react-icons/fa"
    tag = "FaTired"


class FaToggleOff(rx.Component):
    library = "react-icons/fa"
    tag = "FaToggleOff"


class FaToggleOn(rx.Component):
    library = "react-icons/fa"
    tag = "FaToggleOn"


class FaToiletPaperSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaToiletPaperSlash"


class FaToiletPaper(rx.Component):
    library = "react-icons/fa"
    tag = "FaToiletPaper"


class FaToilet(rx.Component):
    library = "react-icons/fa"
    tag = "FaToilet"


class FaToolbox(rx.Component):
    library = "react-icons/fa"
    tag = "FaToolbox"


class FaTools(rx.Component):
    library = "react-icons/fa"
    tag = "FaTools"


class FaTooth(rx.Component):
    library = "react-icons/fa"
    tag = "FaTooth"


class FaTorah(rx.Component):
    library = "react-icons/fa"
    tag = "FaTorah"


class FaToriiGate(rx.Component):
    library = "react-icons/fa"
    tag = "FaToriiGate"


class FaTractor(rx.Component):
    library = "react-icons/fa"
    tag = "FaTractor"


class FaTrademark(rx.Component):
    library = "react-icons/fa"
    tag = "FaTrademark"


class FaTrafficLight(rx.Component):
    library = "react-icons/fa"
    tag = "FaTrafficLight"


class FaTrailer(rx.Component):
    library = "react-icons/fa"
    tag = "FaTrailer"


class FaTrain(rx.Component):
    library = "react-icons/fa"
    tag = "FaTrain"


class FaTram(rx.Component):
    library = "react-icons/fa"
    tag = "FaTram"


class FaTransgenderAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaTransgenderAlt"


class FaTransgender(rx.Component):
    library = "react-icons/fa"
    tag = "FaTransgender"


class FaTrashAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaTrashAlt"


class FaTrashRestoreAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaTrashRestoreAlt"


class FaTrashRestore(rx.Component):
    library = "react-icons/fa"
    tag = "FaTrashRestore"


class FaTrash(rx.Component):
    library = "react-icons/fa"
    tag = "FaTrash"


class FaTree(rx.Component):
    library = "react-icons/fa"
    tag = "FaTree"


class FaTrophy(rx.Component):
    library = "react-icons/fa"
    tag = "FaTrophy"


class FaTruckLoading(rx.Component):
    library = "react-icons/fa"
    tag = "FaTruckLoading"


class FaTruckMonster(rx.Component):
    library = "react-icons/fa"
    tag = "FaTruckMonster"


class FaTruckMoving(rx.Component):
    library = "react-icons/fa"
    tag = "FaTruckMoving"


class FaTruckPickup(rx.Component):
    library = "react-icons/fa"
    tag = "FaTruckPickup"


class FaTruck(rx.Component):
    library = "react-icons/fa"
    tag = "FaTruck"


class FaTshirt(rx.Component):
    library = "react-icons/fa"
    tag = "FaTshirt"


class FaTty(rx.Component):
    library = "react-icons/fa"
    tag = "FaTty"


class FaTv(rx.Component):
    library = "react-icons/fa"
    tag = "FaTv"


class FaUmbrellaBeach(rx.Component):
    library = "react-icons/fa"
    tag = "FaUmbrellaBeach"


class FaUmbrella(rx.Component):
    library = "react-icons/fa"
    tag = "FaUmbrella"


class FaUnderline(rx.Component):
    library = "react-icons/fa"
    tag = "FaUnderline"


class FaUndoAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaUndoAlt"


class FaUndo(rx.Component):
    library = "react-icons/fa"
    tag = "FaUndo"


class FaUniversalAccess(rx.Component):
    library = "react-icons/fa"
    tag = "FaUniversalAccess"


class FaUniversity(rx.Component):
    library = "react-icons/fa"
    tag = "FaUniversity"


class FaUnlink(rx.Component):
    library = "react-icons/fa"
    tag = "FaUnlink"


class FaUnlockAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaUnlockAlt"


class FaUnlock(rx.Component):
    library = "react-icons/fa"
    tag = "FaUnlock"


class FaUpload(rx.Component):
    library = "react-icons/fa"
    tag = "FaUpload"


class FaUserAltSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserAltSlash"


class FaUserAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserAlt"


class FaUserAstronaut(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserAstronaut"


class FaUserCheck(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserCheck"


class FaUserCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserCircle"


class FaUserClock(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserClock"


class FaUserCog(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserCog"


class FaUserEdit(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserEdit"


class FaUserFriends(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserFriends"


class FaUserGraduate(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserGraduate"


class FaUserInjured(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserInjured"


class FaUserLock(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserLock"


class FaUserMd(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserMd"


class FaUserMinus(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserMinus"


class FaUserNinja(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserNinja"


class FaUserNurse(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserNurse"


class FaUserPlus(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserPlus"


class FaUserSecret(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserSecret"


class FaUserShield(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserShield"


class FaUserSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserSlash"


class FaUserTag(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserTag"


class FaUserTie(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserTie"


class FaUserTimes(rx.Component):
    library = "react-icons/fa"
    tag = "FaUserTimes"


class FaUser(rx.Component):
    library = "react-icons/fa"
    tag = "FaUser"


class FaUsersCog(rx.Component):
    library = "react-icons/fa"
    tag = "FaUsersCog"


class FaUsersSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaUsersSlash"


class FaUsers(rx.Component):
    library = "react-icons/fa"
    tag = "FaUsers"


class FaUtensilSpoon(rx.Component):
    library = "react-icons/fa"
    tag = "FaUtensilSpoon"


class FaUtensils(rx.Component):
    library = "react-icons/fa"
    tag = "FaUtensils"


class FaVectorSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaVectorSquare"


class FaVenusDouble(rx.Component):
    library = "react-icons/fa"
    tag = "FaVenusDouble"


class FaVenusMars(rx.Component):
    library = "react-icons/fa"
    tag = "FaVenusMars"


class FaVenus(rx.Component):
    library = "react-icons/fa"
    tag = "FaVenus"


class FaVestPatches(rx.Component):
    library = "react-icons/fa"
    tag = "FaVestPatches"


class FaVest(rx.Component):
    library = "react-icons/fa"
    tag = "FaVest"


class FaVial(rx.Component):
    library = "react-icons/fa"
    tag = "FaVial"


class FaVials(rx.Component):
    library = "react-icons/fa"
    tag = "FaVials"


class FaVideoSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaVideoSlash"


class FaVideo(rx.Component):
    library = "react-icons/fa"
    tag = "FaVideo"


class FaVihara(rx.Component):
    library = "react-icons/fa"
    tag = "FaVihara"


class FaVirusSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaVirusSlash"


class FaVirus(rx.Component):
    library = "react-icons/fa"
    tag = "FaVirus"


class FaViruses(rx.Component):
    library = "react-icons/fa"
    tag = "FaViruses"


class FaVoicemail(rx.Component):
    library = "react-icons/fa"
    tag = "FaVoicemail"


class FaVolleyballBall(rx.Component):
    library = "react-icons/fa"
    tag = "FaVolleyballBall"


class FaVolumeDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaVolumeDown"


class FaVolumeMute(rx.Component):
    library = "react-icons/fa"
    tag = "FaVolumeMute"


class FaVolumeOff(rx.Component):
    library = "react-icons/fa"
    tag = "FaVolumeOff"


class FaVolumeUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaVolumeUp"


class FaVoteYea(rx.Component):
    library = "react-icons/fa"
    tag = "FaVoteYea"


class FaVrCardboard(rx.Component):
    library = "react-icons/fa"
    tag = "FaVrCardboard"


class FaWalking(rx.Component):
    library = "react-icons/fa"
    tag = "FaWalking"


class FaWallet(rx.Component):
    library = "react-icons/fa"
    tag = "FaWallet"


class FaWarehouse(rx.Component):
    library = "react-icons/fa"
    tag = "FaWarehouse"


class FaWater(rx.Component):
    library = "react-icons/fa"
    tag = "FaWater"


class FaWaveSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaWaveSquare"


class FaWeightHanging(rx.Component):
    library = "react-icons/fa"
    tag = "FaWeightHanging"


class FaWeight(rx.Component):
    library = "react-icons/fa"
    tag = "FaWeight"


class FaWheelchair(rx.Component):
    library = "react-icons/fa"
    tag = "FaWheelchair"


class FaWifi(rx.Component):
    library = "react-icons/fa"
    tag = "FaWifi"


class FaWind(rx.Component):
    library = "react-icons/fa"
    tag = "FaWind"


class FaWindowClose(rx.Component):
    library = "react-icons/fa"
    tag = "FaWindowClose"


class FaWindowMaximize(rx.Component):
    library = "react-icons/fa"
    tag = "FaWindowMaximize"


class FaWindowMinimize(rx.Component):
    library = "react-icons/fa"
    tag = "FaWindowMinimize"


class FaWindowRestore(rx.Component):
    library = "react-icons/fa"
    tag = "FaWindowRestore"


class FaWineBottle(rx.Component):
    library = "react-icons/fa"
    tag = "FaWineBottle"


class FaWineGlassAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaWineGlassAlt"


class FaWineGlass(rx.Component):
    library = "react-icons/fa"
    tag = "FaWineGlass"


class FaWonSign(rx.Component):
    library = "react-icons/fa"
    tag = "FaWonSign"


class FaWrench(rx.Component):
    library = "react-icons/fa"
    tag = "FaWrench"


class FaXRay(rx.Component):
    library = "react-icons/fa"
    tag = "FaXRay"


class FaYenSign(rx.Component):
    library = "react-icons/fa"
    tag = "FaYenSign"


class FaYinYang(rx.Component):
    library = "react-icons/fa"
    tag = "FaYinYang"


class FaRegAddressBook(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegAddressBook"


class FaRegAddressCard(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegAddressCard"


class FaRegAngry(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegAngry"


class FaRegArrowAltCircleDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegArrowAltCircleDown"


class FaRegArrowAltCircleLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegArrowAltCircleLeft"


class FaRegArrowAltCircleRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegArrowAltCircleRight"


class FaRegArrowAltCircleUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegArrowAltCircleUp"


class FaRegBellSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegBellSlash"


class FaRegBell(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegBell"


class FaRegBookmark(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegBookmark"


class FaRegBuilding(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegBuilding"


class FaRegCalendarAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCalendarAlt"


class FaRegCalendarCheck(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCalendarCheck"


class FaRegCalendarMinus(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCalendarMinus"


class FaRegCalendarPlus(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCalendarPlus"


class FaRegCalendarTimes(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCalendarTimes"


class FaRegCalendar(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCalendar"


class FaRegCaretSquareDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCaretSquareDown"


class FaRegCaretSquareLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCaretSquareLeft"


class FaRegCaretSquareRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCaretSquareRight"


class FaRegCaretSquareUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCaretSquareUp"


class FaRegChartBar(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegChartBar"


class FaRegCheckCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCheckCircle"


class FaRegCheckSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCheckSquare"


class FaRegCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCircle"


class FaRegClipboard(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegClipboard"


class FaRegClock(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegClock"


class FaRegClone(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegClone"


class FaRegClosedCaptioning(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegClosedCaptioning"


class FaRegCommentAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCommentAlt"


class FaRegCommentDots(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCommentDots"


class FaRegComment(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegComment"


class FaRegComments(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegComments"


class FaRegCompass(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCompass"


class FaRegCopy(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCopy"


class FaRegCopyright(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCopyright"


class FaRegCreditCard(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegCreditCard"


class FaRegDizzy(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegDizzy"


class FaRegDotCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegDotCircle"


class FaRegEdit(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegEdit"


class FaRegEnvelopeOpen(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegEnvelopeOpen"


class FaRegEnvelope(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegEnvelope"


class FaRegEyeSlash(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegEyeSlash"


class FaRegEye(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegEye"


class FaRegFileAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFileAlt"


class FaRegFileArchive(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFileArchive"


class FaRegFileAudio(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFileAudio"


class FaRegFileCode(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFileCode"


class FaRegFileExcel(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFileExcel"


class FaRegFileImage(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFileImage"


class FaRegFilePdf(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFilePdf"


class FaRegFilePowerpoint(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFilePowerpoint"


class FaRegFileVideo(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFileVideo"


class FaRegFileWord(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFileWord"


class FaRegFile(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFile"


class FaRegFlag(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFlag"


class FaRegFlushed(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFlushed"


class FaRegFolderOpen(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFolderOpen"


class FaRegFolder(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFolder"


class FaRegFontAwesomeLogoFull(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFontAwesomeLogoFull"


class FaRegFrownOpen(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFrownOpen"


class FaRegFrown(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFrown"


class FaRegFutbol(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegFutbol"


class FaRegGem(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGem"


class FaRegGrimace(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrimace"


class FaRegGrinAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrinAlt"


class FaRegGrinBeamSweat(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrinBeamSweat"


class FaRegGrinBeam(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrinBeam"


class FaRegGrinHearts(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrinHearts"


class FaRegGrinSquintTears(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrinSquintTears"


class FaRegGrinSquint(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrinSquint"


class FaRegGrinStars(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrinStars"


class FaRegGrinTears(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrinTears"


class FaRegGrinTongueSquint(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrinTongueSquint"


class FaRegGrinTongueWink(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrinTongueWink"


class FaRegGrinTongue(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrinTongue"


class FaRegGrinWink(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrinWink"


class FaRegGrin(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegGrin"


class FaRegHandLizard(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHandLizard"


class FaRegHandPaper(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHandPaper"


class FaRegHandPeace(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHandPeace"


class FaRegHandPointDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHandPointDown"


class FaRegHandPointLeft(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHandPointLeft"


class FaRegHandPointRight(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHandPointRight"


class FaRegHandPointUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHandPointUp"


class FaRegHandPointer(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHandPointer"


class FaRegHandRock(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHandRock"


class FaRegHandScissors(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHandScissors"


class FaRegHandSpock(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHandSpock"


class FaRegHandshake(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHandshake"


class FaRegHdd(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHdd"


class FaRegHeart(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHeart"


class FaRegHospital(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHospital"


class FaRegHourglass(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegHourglass"


class FaRegIdBadge(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegIdBadge"


class FaRegIdCard(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegIdCard"


class FaRegImage(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegImage"


class FaRegImages(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegImages"


class FaRegKeyboard(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegKeyboard"


class FaRegKissBeam(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegKissBeam"


class FaRegKissWinkHeart(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegKissWinkHeart"


class FaRegKiss(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegKiss"


class FaRegLaughBeam(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegLaughBeam"


class FaRegLaughSquint(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegLaughSquint"


class FaRegLaughWink(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegLaughWink"


class FaRegLaugh(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegLaugh"


class FaRegLemon(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegLemon"


class FaRegLifeRing(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegLifeRing"


class FaRegLightbulb(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegLightbulb"


class FaRegListAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegListAlt"


class FaRegMap(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegMap"


class FaRegMehBlank(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegMehBlank"


class FaRegMehRollingEyes(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegMehRollingEyes"


class FaRegMeh(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegMeh"


class FaRegMinusSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegMinusSquare"


class FaRegMoneyBillAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegMoneyBillAlt"


class FaRegMoon(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegMoon"


class FaRegNewspaper(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegNewspaper"


class FaRegObjectGroup(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegObjectGroup"


class FaRegObjectUngroup(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegObjectUngroup"


class FaRegPaperPlane(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegPaperPlane"


class FaRegPauseCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegPauseCircle"


class FaRegPlayCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegPlayCircle"


class FaRegPlusSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegPlusSquare"


class FaRegQuestionCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegQuestionCircle"


class FaRegRegistered(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegRegistered"


class FaRegSadCry(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegSadCry"


class FaRegSadTear(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegSadTear"


class FaRegSave(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegSave"


class FaRegShareSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegShareSquare"


class FaRegSmileBeam(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegSmileBeam"


class FaRegSmileWink(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegSmileWink"


class FaRegSmile(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegSmile"


class FaRegSnowflake(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegSnowflake"


class FaRegSquare(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegSquare"


class FaRegStarHalf(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegStarHalf"


class FaRegStar(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegStar"


class FaRegStickyNote(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegStickyNote"


class FaRegStopCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegStopCircle"


class FaRegSun(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegSun"


class FaRegSurprise(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegSurprise"


class FaRegThumbsDown(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegThumbsDown"


class FaRegThumbsUp(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegThumbsUp"


class FaRegTimesCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegTimesCircle"


class FaRegTired(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegTired"


class FaRegTrashAlt(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegTrashAlt"


class FaRegUserCircle(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegUserCircle"


class FaRegUser(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegUser"


class FaRegWindowClose(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegWindowClose"


class FaRegWindowMaximize(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegWindowMaximize"


class FaRegWindowMinimize(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegWindowMinimize"


class FaRegWindowRestore(rx.Component):
    library = "react-icons/fa"
    tag = "FaRegWindowRestore"


